@@ -6,18 +6,18 @@ import (
 	"fmt"
 	"os"
 	"os/signal"
-	"path/filepath"
 	"syscall"
 
 	"github.com/spf13/cobra"
 
-	"github.com/styrainc/regal/internal/lsp"
-	"github.com/styrainc/regal/internal/lsp/log"
-	"github.com/styrainc/regal/pkg/version"
+	"github.com/open-policy-agent/regal/internal/lsp"
+	"github.com/open-policy-agent/regal/internal/lsp/connection"
+	"github.com/open-policy-agent/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/pkg/version"
 )
 
 func init() {
-	verboseLogging := false
+	verbose := false
 
 	languageServerCommand := &cobra.Command{
 		Use:   "language-server",
@@ -28,37 +28,23 @@ func init() {
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
 
-			exe, err := os.Executable()
-			if err != nil {
+			if exe, err := os.Executable(); err != nil {
 				fmt.Fprintln(os.Stderr, "error getting executable:", err)
 			} else {
-				absPath, err := filepath.Abs(exe)
-				if err != nil {
-					fmt.Fprintln(os.Stderr, "error getting executable path:", err)
-				} else {
-					fmt.Fprintf(
-						os.Stderr,
-						"Regal Language Server (path: %s, version: %s)\n",
-						absPath,
-						cmp.Or(version.Version, "Unknown"),
-					)
-				}
+				msg := "Regal Language Server (path: %s, version: %s)\n"
+				fmt.Fprintf(os.Stderr, msg, exe, cmp.Or(version.Version, "Unknown"))
 			}
 
-			opts := &lsp.LanguageServerOptions{
-				LogWriter: os.Stderr,
-				LogLevel:  log.LevelMessage,
+			if os.Getenv("REGAL_DEBUG") != "" {
+				fmt.Fprintln(os.Stderr, "Debug mode enabled")
+				verbose = true
 			}
 
+			opts := &lsp.LanguageServerOptions{Logger: log.NewLogger(log.LevelMessage, os.Stderr)}
 			ls := lsp.NewLanguageServer(ctx, opts)
 
-			conn := lsp.NewConnectionFromLanguageServer(ctx, ls.Handle, &lsp.ConnectionOptions{
-				LoggingConfig: lsp.ConnectionLoggingConfig{
-					Writer:      os.Stderr,
-					LogInbound:  verboseLogging,
-					LogOutbound: verboseLogging,
-				},
-			})
+			conf := connection.LoggingConfig{Logger: opts.Logger, LogInbound: verbose, LogOutbound: verbose}
+			conn := connection.New(ctx, ls.Handle, &connection.Options{LoggingConfig: conf})
 			defer conn.Close()
 
 			ls.SetConn(conn)
@@ -84,7 +70,7 @@ func init() {
 		}),
 	}
 
-	languageServerCommand.Flags().BoolVarP(&verboseLogging, "verbose", "v", verboseLogging, "Enable verbose logging")
+	languageServerCommand.Flags().BoolVarP(&verbose, "verbose", "v", verbose, "Enable verbose logging")
 
 	addPprofFlag(languageServerCommand.Flags())
 
