@@ -1,4 +1,3 @@
-//nolint:wrapcheck
 package cmd
 
 import (
@@ -10,9 +9,8 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/util"
 
-	rp "github.com/styrainc/regal/internal/parse"
-
-	"github.com/styrainc/roast/pkg/encoding"
+	rp "github.com/open-policy-agent/regal/internal/parse"
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 )
 
 func init() {
