@@ -27,13 +27,12 @@ import (
 	outil "github.com/open-policy-agent/opa/v1/util"
 	"github.com/open-policy-agent/opa/v1/version"
 
-	rbundle "github.com/styrainc/regal/bundle"
-	"github.com/styrainc/regal/internal/compile"
-	rio "github.com/styrainc/regal/internal/io"
-	"github.com/styrainc/regal/pkg/builtins"
-	"github.com/styrainc/regal/pkg/config"
-
-	rutil "github.com/styrainc/roast/pkg/util"
+	rbundle "github.com/open-policy-agent/regal/bundle"
+	"github.com/open-policy-agent/regal/internal/compile"
+	rio "github.com/open-policy-agent/regal/internal/io"
+	"github.com/open-policy-agent/regal/internal/util"
+	"github.com/open-policy-agent/regal/pkg/builtins"
+	"github.com/open-policy-agent/regal/pkg/config"
 )
 
 const benchmarkGoBenchOutput = "gobench"
@@ -155,12 +154,14 @@ func opaTest(args []string) int {
 		return 1
 	}
 
+	regalBundle := rbundle.LoadedBundle()
+
 	if err := store.Write(
 		ctx,
 		txn,
 		storage.AddOp,
 		storage.MustParsePath("/regal"),
-		rbundle.LoadedBundle.Data["regal"],
+		regalBundle.Data["regal"],
 	); err != nil {
 		panic(err)
 	}
@@ -182,7 +183,7 @@ func opaTest(args []string) int {
 		WithEnablePrintStatements(!testParams.benchmark).
 		WithSchemas(compile.RegalSchemaSet()).
 		WithUseTypeCheckAnnotations(true).
-		WithModuleLoader(moduleLoader(&rbundle.LoadedBundle)).
+		WithModuleLoader(moduleLoader(regalBundle)).
 		WithRewriteTestRules(testParams.varValues)
 
 	if testParams.threshold > 0 && !testParams.coverage {
@@ -230,7 +231,7 @@ func opaTest(args []string) int {
 func moduleLoader(regalRules *bundle.Bundle) ast.ModuleLoader {
 	// We use the package declarations to know which modules we still need, and return
 	// those from the embedded regal bundle.
-	extra := rutil.NewSet[string]()
+	extra := util.NewSet[string]()
 	for _, mod := range regalRules.Modules {
 		extra.Add(mod.Parsed.Package.Path.String())
 	}
