@@ -1,15 +1,15 @@
 package cmd
 
 import (
+	"cmp"
 	"fmt"
 	"log"
 	"os"
 
 	"github.com/spf13/cobra"
 
-	"github.com/styrainc/regal/pkg/version"
-
-	"github.com/styrainc/roast/pkg/encoding"
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
+	"github.com/open-policy-agent/regal/pkg/version"
 )
 
 type versionCommandParams struct {
@@ -25,9 +25,8 @@ func init() {
 		Long:  "Show the version and other build-time metadata for the running Regal binary.",
 
 		PreRunE: func(*cobra.Command, []string) error {
-			if params.format == "" {
-				params.format = "pretty"
-			} else if params.format != "json" && params.format != "pretty" {
+			params.format = cmp.Or(params.format, formatPretty)
+			if params.format != formatJSON && params.format != formatPretty {
 				return fmt.Errorf("invalid format: %s", params.format)
 			}
 
