@@ -18,14 +18,19 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/internal/capabilities/embedded"
+	"github.com/open-policy-agent/regal/internal/capabilities/embedded"
+	"github.com/open-policy-agent/regal/internal/util"
 )
 
 const (
 	engineOPA  = "opa"
 	engineEOPA = "eopa"
+
+	DefaultURL = "regal:///capabilities/default"
 )
 
+var driveLetterPattern = regexp.MustCompile(`^\/[a-zA-Z]:`)
+
 // Lookup attempts to retrieve capabilities from the requested RFC3986
 // compliant URL.
 //
@@ -77,17 +82,14 @@ func lookupEmbeddedURL(parsedURL *url.URL) (*ast.Capabilities, error) {
 	// would arguably be more elegant to do this with regex and named
 	// capture groups, but I trust the stdlib URL and path splitting
 	// implementations more.
-	urlPath := parsedURL.Path
-	urlPath = path.Clean(urlPath)
 	elems := make([]string, 0)
-	dir := urlPath
+	dir := path.Clean(parsedURL.Path)
 
 	var file string
 
 	for dir != "" {
 		// leading and trailing / symbols confuse path.Split()
-		dir = strings.Trim(dir, "/")
-		dir, file = path.Split(dir)
+		dir, file = path.Split(strings.Trim(dir, "/"))
 		elems = append(elems, file)
 	}
 
@@ -171,21 +173,9 @@ func lookupEmbeddedURL(parsedURL *url.URL) (*ast.Capabilities, error) {
 
 	switch engine {
 	case engineOPA:
-		// This obtuse error handling is required to make the linter
-		// happy.
-		caps, err := ast.LoadCapabilitiesVersion(version)
-		if err != nil {
-			return nil, fmt.Errorf("failed to load capabilities due to error: %w", err)
-		}
-
-		return caps, nil
+		return util.Wrap(ast.LoadCapabilitiesVersion(version))("failed to load capabilities")
 	case engineEOPA:
-		caps, err := embedded.LoadCapabilitiesVersion(engineEOPA, version)
-		if err != nil {
-			return nil, fmt.Errorf("failed to load capabilities due to error: %w", err)
-		}
-
-		return caps, nil
+		return util.Wrap(embedded.LoadCapabilitiesVersion(engineEOPA, version))("failed to load capabilities")
 	default:
 		return nil, fmt.Errorf("engine '%s' not present in embedded capabilities database", engine)
 	}
@@ -194,24 +184,14 @@ func lookupEmbeddedURL(parsedURL *url.URL) (*ast.Capabilities, error) {
 func lookupFileURL(parsedURL *url.URL) (*ast.Capabilities, error) {
 	// the provided URL's path could be either a windows path or a unix one
 	// we must account for both cases by stripping the leading / if found
-	driveLetterPattern := regexp.MustCompile(`^\/[a-zA-Z]:`)
-
 	path := parsedURL.Path
 	if driveLetterPattern.MatchString(path) {
 		path = path[1:]
 	}
 
-	fd, err := os.Open(path)
-	if err != nil {
-		return nil, fmt.Errorf("error opening file '%s': %w", path, err)
-	}
-
-	caps, err := ast.LoadCapabilitiesJSON(fd)
-	if err != nil {
-		return nil, fmt.Errorf("failed to load capabilities due to error: %w", err)
-	}
-
-	return caps, nil
+	return util.WithOpen(path, func(fd *os.File) (*ast.Capabilities, error) {
+		return util.Wrap(ast.LoadCapabilitiesJSON(fd))("failed to load capabilities")
+	})
 }
 
 func lookupWebURL(ctx context.Context, parsedURL *url.URL) (*ast.Capabilities, error) {
@@ -228,12 +208,7 @@ func lookupWebURL(ctx context.Context, parsedURL *url.URL) (*ast.Capabilities, e
 	}
 	defer resp.Body.Close()
 
-	caps, err := ast.LoadCapabilitiesJSON(resp.Body)
-	if err != nil {
-		return nil, fmt.Errorf("failed to load capabilities due to error: %w", err)
-	}
-
-	return caps, nil
+	return util.Wrap(ast.LoadCapabilitiesJSON(resp.Body))("failed to load capabilities")
 }
 
 // semverSort uses the semver library to perform the string comparisons during
@@ -254,8 +229,8 @@ func semverSort(stringVersions []string) {
 		iVers, ok := vCache[iStr]
 		if !ok {
 			var err error
-			iVers, err = semver.NewVersion(iStr)
 
+			iVers, err = semver.NewVersion(iStr)
 			if err != nil {
 				iValid = false
 			} else {
@@ -266,8 +241,8 @@ func semverSort(stringVersions []string) {
 		jVers, ok := vCache[jStr]
 		if !ok {
 			var err error
-			jVers, err = semver.NewVersion(jStr)
 
+			jVers, err = semver.NewVersion(jStr)
 			if err != nil {
 				jValid = false
 			} else {
@@ -319,8 +294,5 @@ func List() (map[string][]string, error) {
 	semverSort(opaCaps)
 	semverSort(eopaCaps)
 
-	return map[string][]string{
-		engineOPA:  opaCaps,
-		engineEOPA: eopaCaps,
-	}, nil
+	return map[string][]string{engineOPA: opaCaps, engineEOPA: eopaCaps}, nil
 }
