@@ -2,23 +2,22 @@ package capabilities
 
 import (
 	"path/filepath"
+	"runtime"
 	"testing"
+
+	"github.com/open-policy-agent/regal/internal/testutil"
 )
 
 func TestLookupFromFile(t *testing.T) {
 	t.Parallel()
 
-	// Test that we are able to load a capabilities file using a file://
-	// URL.
-
-	path, err := filepath.Abs("./testdata/capabilities.json")
-	if err != nil {
-		t.Fatalf("could not determine absolute path to test capabilities file: %v", err)
+	// TODO: https://github.com/open-policy-agent/regal/issues/1683
+	if runtime.GOOS == "windows" {
+		t.Skip()
 	}
 
-	urlForPath := "file://" + path
-
-	caps, err := Lookup(t.Context(), urlForPath)
+	// Test that we are able to load a capabilities file using a file:// URL.
+	caps, err := Lookup(t.Context(), "file://"+testutil.Must(filepath.Abs("./testdata/capabilities.json"))(t))
 	if err != nil {
 		t.Errorf("unexpected error from Lookup: %v", err)
 	}
@@ -35,14 +34,8 @@ func TestLookupFromFile(t *testing.T) {
 func TestLookupFromEmbedded(t *testing.T) {
 	t.Parallel()
 
-	// Test that we can load a one of the existing OPA capabilities files
-	// via the embedded database.
-
-	caps, err := Lookup(t.Context(), "regal:///capabilities/opa/v0.55.0")
-	if err != nil {
-		t.Errorf("unexpected error from Lookup: %v", err)
-	}
-
+	// existing OPA capabilities files from embedded database.
+	caps := testutil.Must(Lookup(t.Context(), "regal:///capabilities/opa/v0.55.0"))(t)
 	if len(caps.Builtins) != 193 {
 		t.Errorf("OPA v0.55.0 capabilities should have 193 builtins, not %d", len(caps.Builtins))
 	}
@@ -73,10 +66,7 @@ func TestSemverSort(t *testing.T) {
 		},
 	}
 
-	for i, c := range cases {
-		t.Logf("----- TestSemverSort[%d]", i)
-		t.Logf("// %s\n", c.note)
-
+	for _, c := range cases {
 		// Note that this actually sorts the input in-place, which is
 		// fine since we won't re-visit the same test case twice.
 		semverSort(c.input)
