@@ -7,11 +7,10 @@ import (
 	"github.com/open-policy-agent/opa/v1/ast"
 	outil "github.com/open-policy-agent/opa/v1/util"
 
-	"github.com/styrainc/regal/internal/lsp/types"
-	"github.com/styrainc/regal/pkg/report"
-
-	"github.com/styrainc/roast/pkg/util"
-	"github.com/styrainc/roast/pkg/util/concurrent"
+	"github.com/open-policy-agent/regal/internal/lsp/types"
+	"github.com/open-policy-agent/regal/internal/util"
+	"github.com/open-policy-agent/regal/pkg/report"
+	"github.com/open-policy-agent/regal/pkg/roast/util/concurrent"
 )
 
 // Cache is used to store: current file contents (which includes unsaved changes), the latest parsed modules, and
@@ -320,7 +319,7 @@ func (c *Cache) Delete(fileURI string) {
 	c.successfulParseLineCounts.Delete(fileURI)
 }
 
-func UpdateCacheForURIFromDisk(cache *Cache, fileURI, path string) (bool, string, error) {
+func (c *Cache) UpdateForURIFromDisk(fileURI, path string) (bool, string, error) {
 	content, err := os.ReadFile(path)
 	if err != nil {
 		return false, "", fmt.Errorf("failed to read file: %w", err)
@@ -328,12 +327,12 @@ func UpdateCacheForURIFromDisk(cache *Cache, fileURI, path string) (bool, string
 
 	currentContent := outil.ByteSliceToString(content)
 
-	cachedContent, ok := cache.GetFileContents(fileURI)
+	cachedContent, ok := c.GetFileContents(fileURI)
 	if ok && cachedContent == currentContent {
 		return false, cachedContent, nil
 	}
 
-	cache.SetFileContents(fileURI, currentContent)
+	c.SetFileContents(fileURI, currentContent)
 
 	return true, currentContent, nil
 }
