@@ -1,5 +1,7 @@
 package clients
 
+import "strings"
+
 // Identifier represent different supported clients and can be used to toggle or change
 // server behavior based on the client.
 type Identifier uint8
@@ -10,13 +12,14 @@ const (
 	IdentifierGoTest
 	IdentifierZed
 	IdentifierNeovim
+	IdentifierIntelliJ
 )
 
-// DetermineClientIdentifier is used to determine the Regal client identifier
+// DetermineIdentifier is used to determine the Regal client identifier
 // based on the client name.
 // Clients with identifiers here should be featured on the 'Editor Support'
 // page in the documentation (https://docs.styra.com/regal/editor-support).
-func DetermineClientIdentifier(clientName string) Identifier {
+func DetermineIdentifier(clientName string) Identifier {
 	switch clientName {
 	case "go test":
 		return IdentifierGoTest
@@ -30,5 +33,10 @@ func DetermineClientIdentifier(clientName string) Identifier {
 		return IdentifierNeovim
 	}
 
+	// check for IntelliJ using contains since version is also set in the name
+	if strings.Contains(clientName, "IntelliJ") {
+		return IdentifierIntelliJ
+	}
+
 	return IdentifierGeneric
 }
