@@ -5,41 +5,25 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/internal/lsp/cache"
-	"github.com/styrainc/regal/internal/lsp/completions/providers"
-	"github.com/styrainc/regal/internal/lsp/types"
+	"github.com/open-policy-agent/regal/internal/lsp/cache"
+	"github.com/open-policy-agent/regal/internal/lsp/completions/providers"
+	"github.com/open-policy-agent/regal/internal/lsp/types"
 )
 
 func TestManagerEarlyExitInsideComment(t *testing.T) {
 	t.Parallel()
 
-	c := cache.NewCache()
 	fileURI := "file:///foo/bar/file.rego"
+	fileContents := "package p\n\n# foo := http\n"
 
-	fileContents := `package p
-
-# foo := http
-`
-
-	module := ast.MustParseModule(fileContents)
-
+	c := cache.NewCache()
 	c.SetFileContents(fileURI, fileContents)
-	c.SetModule(fileURI, module)
+	c.SetModule(fileURI, ast.MustParseModule(fileContents))
 
 	mgr := NewManager(c, &ManagerOptions{})
 	mgr.RegisterProvider(&providers.BuiltIns{})
 
-	completionParams := types.CompletionParams{
-		TextDocument: types.TextDocumentIdentifier{
-			URI: fileURI,
-		},
-		Position: types.Position{
-			Line:      2,
-			Character: 13,
-		},
-	}
-
-	completions, err := mgr.Run(t.Context(), completionParams, nil)
+	completions, err := mgr.Run(t.Context(), types.NewCompletionParams(fileURI, 2, 13, nil), nil)
 	if err != nil {
 		t.Fatalf("Unexpected error: %v", err)
 	}
