@@ -7,9 +7,9 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/internal/lsp/rego"
-	"github.com/styrainc/regal/internal/lsp/types"
-	rparse "github.com/styrainc/regal/internal/parse"
+	"github.com/open-policy-agent/regal/internal/lsp/rego"
+	"github.com/open-policy-agent/regal/internal/lsp/types"
+	rparse "github.com/open-policy-agent/regal/internal/parse"
 )
 
 func TestForModule_Package(t *testing.T) {
@@ -125,7 +125,6 @@ deny contains "strings" if true
 pi := 3.14
 `)
 	bis := rego.BuiltinsForCapabilities(ast.CapabilitiesForThisVersion())
-
 	items := DefinedInModule(mod, bis)
 
 	expectedRefs := map[string]types.Ref{
@@ -182,7 +181,7 @@ A function that's really funky`,
 		}
 
 		if items[key].Kind != item.Kind {
-			t.Errorf("expected documentation kind %q, got %q", item.Description, items[key].Description)
+			t.Errorf("expected kind %q, got %q", item.Kind, items[key].Kind)
 		}
 
 		if items[key].Detail != item.Detail {
