@@ -9,13 +9,12 @@ import (
 	"github.com/open-policy-agent/opa/v1/bundle"
 	"github.com/open-policy-agent/opa/v1/rego"
 
-	rbundle "github.com/styrainc/regal/bundle"
-	rio "github.com/styrainc/regal/internal/io"
-	"github.com/styrainc/regal/pkg/builtins"
-	"github.com/styrainc/regal/pkg/config"
-
-	"github.com/styrainc/roast/pkg/rast"
-	"github.com/styrainc/roast/pkg/transform"
+	rbundle "github.com/open-policy-agent/regal/bundle"
+	rio "github.com/open-policy-agent/regal/internal/io"
+	"github.com/open-policy-agent/regal/pkg/builtins"
+	"github.com/open-policy-agent/regal/pkg/config"
+	"github.com/open-policy-agent/regal/pkg/roast/rast"
+	"github.com/open-policy-agent/regal/pkg/roast/transform"
 
 	_ "embed"
 )
@@ -45,14 +44,14 @@ func prepareQuery() (*rego.PreparedEvalQuery, error) {
 	}
 
 	regoArgs := append([]func(*rego.Rego){
-		rego.ParsedBundle("regal", &rbundle.LoadedBundle),
+		rego.ParsedBundle("regal", rbundle.LoadedBundle()),
 		rego.ParsedBundle("internal", &dataBundle),
 		rego.ParsedQuery(refNamesQuery),
 	}, builtins.RegalBuiltinRegoFuncs...)
 
 	preparedQuery, err := rego.New(regoArgs...).PrepareForEval(context.Background())
 	if err != nil {
-		return nil, err //nolint:wrapcheck
+		return nil, err
 	}
 
 	return &preparedQuery, nil
