@@ -7,22 +7,15 @@ import (
 	"testing"
 	"time"
 
-	"github.com/styrainc/regal/internal/lsp/log"
-	"github.com/styrainc/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/internal/testutil"
 )
 
 func TestWatcher(t *testing.T) {
 	t.Parallel()
 
-	tempDir := testutil.TempDirectoryOf(t, map[string]string{
-		"config.yaml": `---
-foo: bar
-`,
-	})
-
-	watcher := NewWatcher(&WatcherOpts{LogFunc: func(l log.Level, s string, a ...any) {
-		t.Logf(l.String()+": "+s, a...)
-	}})
+	tempDir := testutil.TempDirectoryOf(t, map[string]string{"config.yaml": "---\nfoo: bar\n"})
+	watcher := NewWatcher(&WatcherOpts{Logger: log.NewLogger(log.LevelDebug, t.Output())})
 
 	ctx, cancel := context.WithCancel(t.Context())
 	defer cancel()
@@ -43,9 +36,7 @@ foo: bar
 		t.Fatal("timeout waiting for initial config event")
 	}
 
-	newConfigFileContents := `---
-foo: baz
-`
+	newConfigFileContents := "---\nfoo: baz\n"
 	testutil.MustWriteFile(t, configFilePath, []byte(newConfigFileContents))
 
 	select {
