@@ -10,12 +10,12 @@ import (
 	"github.com/open-policy-agent/opa/v1/ast"
 	"github.com/open-policy-agent/opa/v1/types"
 
-	"github.com/styrainc/regal/internal/lsp/cache"
-	"github.com/styrainc/regal/internal/lsp/examples"
-	"github.com/styrainc/regal/internal/lsp/rego"
-	types2 "github.com/styrainc/regal/internal/lsp/types"
-
-	"github.com/styrainc/roast/pkg/util/concurrent"
+	"github.com/open-policy-agent/regal/internal/lsp/cache"
+	"github.com/open-policy-agent/regal/internal/lsp/examples"
+	"github.com/open-policy-agent/regal/internal/lsp/rego"
+	"github.com/open-policy-agent/regal/internal/lsp/rego/query"
+	types2 "github.com/open-policy-agent/regal/internal/lsp/types"
+	"github.com/open-policy-agent/regal/pkg/roast/util/concurrent"
 )
 
 var builtinCache = concurrent.MapOf(make(map[*ast.Builtin]string))
@@ -61,8 +61,7 @@ func CreateHoverContent(builtin *ast.Builtin) string {
 		strings.ReplaceAll(builtin.Name, ".", ""),
 	)
 
-	// Enterprise OPA supports custom links via categories from 1.29.1
-	// https://github.com/StyraInc/enterprise-opa/blob/v1.29.1/capabilities/v1.29.1.json#L5110
+	// EOPA supports custom links via categories from 1.29.1
 	for _, category := range builtin.Categories {
 		if strings.HasPrefix(category, "url=") {
 			link = category[4:]
@@ -72,15 +71,13 @@ func CreateHoverContent(builtin *ast.Builtin) string {
 	}
 
 	title := fmt.Sprintf("[%s](%s)", builtin.Name, link)
-
 	sb := &strings.Builder{}
 
 	sb.WriteString("### ")
 	sb.WriteString(title)
 	sb.WriteString("\n\n")
 
-	exampleLink, ok := examples.GetBuiltInLink(builtin.Name)
-	if ok {
+	if exampleLink, ok := examples.GetBuiltInLink(builtin.Name); ok {
 		fmt.Fprintf(sb, "[View Usage Examples](%s)\n", exampleLink)
 	}
 
@@ -164,13 +161,13 @@ func UpdateBuiltinPositions(cache *cache.Cache, uri string, builtins map[string]
 	return nil
 }
 
-func UpdateKeywordLocations(ctx context.Context, cache *cache.Cache, uri string) error {
+func UpdateKeywordLocations(ctx context.Context, pq *query.Prepared, cache *cache.Cache, uri string) error {
 	fileContents, module, ok := cache.GetContentAndModule(uri)
 	if !ok {
 		return fmt.Errorf("failed to determine keyword locations: missing file contents for uri %q", uri)
 	}
 
-	keywords, err := rego.AllKeywords(ctx, filepath.Base(uri), fileContents, module)
+	keywords, err := rego.AllKeywords(ctx, pq, filepath.Base(uri), fileContents, module)
 	if err != nil {
 		return fmt.Errorf("failed to determine keyword locations: %w", err)
 	}
