@@ -6,12 +6,13 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/internal/lsp/cache"
-	"github.com/styrainc/regal/internal/lsp/types"
-	"github.com/styrainc/regal/internal/parse"
-	"github.com/styrainc/regal/internal/util"
-	"github.com/styrainc/regal/pkg/config"
-	"github.com/styrainc/regal/pkg/report"
+	"github.com/open-policy-agent/regal/internal/lsp/cache"
+	"github.com/open-policy-agent/regal/internal/lsp/types"
+	"github.com/open-policy-agent/regal/internal/parse"
+	"github.com/open-policy-agent/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/internal/util"
+	"github.com/open-policy-agent/regal/pkg/config"
+	"github.com/open-policy-agent/regal/pkg/report"
 )
 
 func TestUpdateParse(t *testing.T) {
@@ -45,7 +46,7 @@ p = true { 1 == }
 			regoVersion: ast.RegoV1,
 			expectedParseErrors: []types.Diagnostic{{
 				Code:  "rego-parse-error",
-				Range: types.Range{Start: types.Position{Line: 2, Character: 13}, End: types.Position{Line: 2, Character: 13}},
+				Range: types.RangeBetween(2, 13, 2, 13),
 			}},
 			expectModule:  false,
 			expectSuccess: false,
@@ -56,7 +57,7 @@ p = true { 1 == }
 			regoVersion: ast.RegoV1,
 			expectedParseErrors: []types.Diagnostic{{
 				Code:  "rego-parse-error",
-				Range: types.Range{Start: types.Position{Line: 0, Character: 0}, End: types.Position{Line: 0, Character: 0}},
+				Range: types.RangeBetween(0, 0, 0, 0),
 			}},
 			expectModule:  false,
 			expectSuccess: false,
@@ -70,7 +71,7 @@ allow if { 1 == 1 }
 			expectSuccess: false,
 			expectedParseErrors: []types.Diagnostic{{
 				Code:  "rego-parse-error",
-				Range: types.Range{Start: types.Position{Line: 1, Character: 0}, End: types.Position{Line: 1, Character: 0}},
+				Range: types.RangeBetween(1, 0, 1, 0),
 			}},
 			regoVersion: ast.RegoV0,
 		},
@@ -98,29 +99,27 @@ allow[msg] { 1 == 1; msg := "hello" }
 		t.Run(testName, func(t *testing.T) {
 			t.Parallel()
 
-			ctx := t.Context()
-
 			c := cache.NewCache()
 			c.SetFileContents(testData.fileURI, testData.content)
 
-			s := NewRegalStore()
-
-			success, err := updateParse(ctx, c, s, testData.fileURI, ast.BuiltinMap, testData.regoVersion)
-			if err != nil {
-				t.Fatalf("unexpected error: %v", err)
-			}
+			success := testutil.Must(updateParse(t.Context(), updateParseOpts{
+				Cache:            c,
+				Store:            NewRegalStore(),
+				FileURI:          testData.fileURI,
+				Builtins:         ast.BuiltinMap,
+				RegoVersion:      testData.regoVersion,
+				WorkspaceRootURI: "",
+			}))(t)
 
 			if success != testData.expectSuccess {
 				t.Fatalf("expected success to be %v, got %v", testData.expectSuccess, success)
 			}
 
-			_, ok := c.GetModule(testData.fileURI)
-			if testData.expectModule && !ok {
+			if _, ok := c.GetModule(testData.fileURI); testData.expectModule && !ok {
 				t.Fatalf("expected module to be set, but it was not")
 			}
 
 			diags, _ := c.GetParseErrors(testData.fileURI)
-
 			if len(testData.expectedParseErrors) != len(diags) {
 				t.Fatalf("expected %v parse errors, got %v", len(testData.expectedParseErrors), len(diags))
 			}
@@ -162,9 +161,7 @@ func TestConvertReportToDiagnostics(t *testing.T) {
 		IsAggregate: true,
 	}
 
-	rpt := &report.Report{
-		Violations: []report.Violation{violation1, violation2},
-	}
+	rpt := &report.Report{Violations: []report.Violation{violation1, violation2}}
 
 	expectedFileDiags := map[string][]types.Diagnostic{
 		"file1": {
@@ -205,35 +202,28 @@ func TestLintWithConfigIgnoreWildcards(t *testing.T) {
 
 	conf := &config.Config{
 		Rules: map[string]config.Category{
-			"idiomatic": {
-				"directory-package-mismatch": config.Rule{
-					Level: "ignore",
-				},
-			},
+			"idiomatic": {"directory-package-mismatch": config.Rule{Level: "ignore"}},
 		},
 	}
 
 	contents := "package p\n\ncamelCase := 1\n"
-	module := parse.MustParseModule(contents)
-	workspaceRootURI := "file:///workspace"
 	fileURI := "file:///workspace/ignore/p.rego"
-	state := cache.NewCache()
 
+	state := cache.NewCache()
 	state.SetFileContents(fileURI, contents)
-	state.SetModule(fileURI, module)
+	state.SetModule(fileURI, parse.MustParseModule(contents))
 	state.SetFileDiagnostics(fileURI, []types.Diagnostic{})
 
-	if err := updateFileDiagnostics(
-		t.Context(),
-		state,
-		conf,
-		fileURI,
-		workspaceRootURI,
-		[]string{"prefer-snake-case"},
-	); err != nil {
-		t.Fatalf("Expected no error, got %v", err)
+	opts := diagnosticsRunOpts{
+		Cache:            state,
+		RegalConfig:      conf,
+		FileURI:          fileURI,
+		WorkspaceRootURI: "file:///workspace",
+		UpdateForRules:   []string{"prefer-snake-case"},
 	}
 
+	testutil.NoErr(updateFileDiagnostics(t.Context(), opts))(t)
+
 	diagnostics, _ := state.GetFileDiagnostics(fileURI)
 	if len(diagnostics) != 1 {
 		t.Fatalf("Expected one diagnostic item, got %v", diagnostics)
@@ -245,31 +235,20 @@ func TestLintWithConfigIgnoreWildcards(t *testing.T) {
 
 	// Clear the diagnostic and update the config with a wildcard ignore
 	// for any file in the ignore directory.
-
 	state.SetFileDiagnostics(fileURI, []types.Diagnostic{})
 
 	conf.Rules["style"] = config.Category{
 		"prefer-snake-case": config.Rule{
-			Level: "error",
-			Ignore: &config.Ignore{
-				Files: []string{"ignore/**"},
-			},
+			Level:  "error",
+			Ignore: &config.Ignore{Files: []string{"ignore/**"}},
 		},
 	}
 
-	if err := updateFileDiagnostics(
-		t.Context(),
-		state,
-		conf,
-		fileURI,
-		workspaceRootURI,
-		[]string{"prefer-snake-case"},
-	); err != nil {
-		t.Fatalf("Expected no error, got %v", err)
-	}
+	opts.UpdateForRules = []string{"prefer-snake-case"}
 
-	diagnostics, _ = state.GetFileDiagnostics(fileURI)
-	if len(diagnostics) != 0 {
+	testutil.NoErr(updateFileDiagnostics(t.Context(), opts))(t)
+
+	if diagnostics, _ := state.GetFileDiagnostics(fileURI); len(diagnostics) != 0 {
 		t.Fatalf("Expected no diagnostics, got %v", diagnostics)
 	}
 }
