@@ -2,14 +2,11 @@ package lsp
 
 import (
 	"context"
-	"errors"
 	"fmt"
 	"io"
 	"net"
 	"path/filepath"
 	"slices"
-	"strings"
-	"sync"
 	"testing"
 	"time"
 
@@ -17,20 +14,22 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/util"
 
-	"github.com/styrainc/regal/internal/lsp/log"
-	"github.com/styrainc/regal/internal/lsp/types"
-
-	"github.com/styrainc/roast/pkg/encoding"
+	"github.com/open-policy-agent/regal/internal/lsp/clients"
+	"github.com/open-policy-agent/regal/internal/lsp/handler"
+	"github.com/open-policy-agent/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/internal/lsp/types"
+	"github.com/open-policy-agent/regal/internal/lsp/uri"
 )
 
-const mainRegoFileName = "/main.rego"
-
-// defaultTimeout is set based on the investigation done as part of
-// https://github.com/StyraInc/regal/issues/931. 20 seconds is 10x the
-// maximum time observed for an operation to complete.
-const defaultTimeout = 20 * time.Second
-
-const defaultBufferedChannelSize = 5
+const (
+	mainRegoFileName = "/main.rego"
+	fileURIScheme    = "file://"
+	// defaultTimeout is set based on the investigation done as part of
+	// https://github.com/open-policy-agent/regal/issues/931. 20 seconds is 10x the
+	// maximum time observed for an operation to complete.
+	defaultTimeout             = 20 * time.Second
+	defaultBufferedChannelSize = 5
+)
 
 // determineTimeout returns a timeout duration based on whether
 // the test suite is running with race detection, if so, a more permissive
@@ -45,51 +44,9 @@ func determineTimeout() time.Duration {
 	return defaultTimeout
 }
 
-const fileURIScheme = "file://"
-
-// NewTestLogger returns an io.Writer that logs to the given testing.T.
-// This is helpful as it can be used to have the server log to the test logger
-// in server tests. It is protected from being written to after the test is
-// over.
-func newTestLogger(t *testing.T) io.Writer {
-	t.Helper()
-
-	tl := &testLogger{t: t, open: true}
-
-	// using cleanup ensure that no goroutines attempt to write to the logger
-	// after the test has been cleaned up
-	t.Cleanup(func() {
-		tl.mu.Lock()
-		defer tl.mu.Unlock()
-		tl.open = false
-	})
-
-	return tl
-}
-
-type testLogger struct {
-	t    *testing.T
-	open bool
-	mu   sync.RWMutex
-}
-
-func (tl *testLogger) Write(p []byte) (n int, err error) {
-	tl.mu.RLock()
-	defer tl.mu.RUnlock()
-
-	if !tl.open {
-		return 0, errors.New("cannot log, test is over")
-	}
-
-	tl.t.Log(strings.TrimSpace(string(p)))
-
-	return len(p), nil
-}
-
 func createAndInitServer(
 	t *testing.T,
 	ctx context.Context,
-	logger io.Writer,
 	tempDir string,
 	clientHandler func(_ context.Context, _ *jsonrpc2.Conn, req *jsonrpc2.Request) (result any, err error),
 ) (
@@ -105,12 +62,10 @@ func createAndInitServer(
 		pollingInterval = 10 * time.Second
 	}
 
+	logger := log.NewLogger(log.LevelDebug, t.Output())
+
 	// set up the server and client connections
-	ls := NewLanguageServer(ctx, &LanguageServerOptions{
-		LogWriter:                logger,
-		LogLevel:                 log.LevelDebug,
-		WorkspaceDiagnosticsPoll: pollingInterval,
-	})
+	ls := NewLanguageServer(ctx, &LanguageServerOptions{Logger: logger, WorkspaceDiagnosticsPoll: pollingInterval})
 
 	go ls.StartDiagnosticsWorker(ctx)
 	go ls.StartConfigWorker(ctx)
@@ -140,12 +95,11 @@ func createAndInitServer(
 	ls.SetConn(connServer)
 
 	request := types.InitializeParams{
-		RootURI:    fileURIScheme + tempDir,
-		ClientInfo: types.Client{Name: "go test"},
+		RootURI:    uri.FromPath(clients.IdentifierGeneric, tempDir),
+		ClientInfo: types.ClientInfo{Name: "go test"},
 	}
 
 	var response types.InitializeResult
-
 	if err := connClient.Call(ctx, "initialize", request, &response); err != nil {
 		t.Fatalf("failed to initialize: %s", err)
 	}
@@ -159,7 +113,7 @@ func createAndInitServer(
 	return ls, connClient
 }
 
-func createClientHandler(
+func createPublishDiagnosticsHandler(
 	t *testing.T,
 	logger io.Writer,
 	messages map[string]chan []string,
@@ -167,43 +121,38 @@ func createClientHandler(
 	t.Helper()
 
 	return func(_ context.Context, _ *jsonrpc2.Conn, req *jsonrpc2.Request) (result any, err error) {
-		if req.Method != "textDocument/publishDiagnostics" {
+		if req.Method != methodTdPublishDiagnostics {
 			fmt.Fprintln(logger, "createClientHandler: unexpected request method:", req.Method)
 
 			return struct{}{}, nil
 		}
 
-		var requestData types.FileDiagnostics
+		return handler.WithParams(req, func(params types.FileDiagnostics) (any, error) {
+			violations := make([]string, len(params.Items))
+			for i, item := range params.Items {
+				violations[i] = item.Code
+			}
 
-		err = encoding.JSON().Unmarshal(*req.Params, &requestData)
-		if err != nil {
-			t.Fatalf("failed to unmarshal diagnostics: %s", err)
-		}
+			slices.Sort(violations)
 
-		violations := make([]string, len(requestData.Items))
-		for i, item := range requestData.Items {
-			violations[i] = item.Code
-		}
+			fileBase := filepath.Base(params.URI)
+			fmt.Fprintln(logger, "createPublishDiagnosticsHandler: queue", fileBase, len(messages[fileBase]))
 
-		slices.Sort(violations)
+			select {
+			case messages[fileBase] <- violations:
+			case <-time.After(1 * time.Second):
+				t.Fatalf("timeout writing to messages channel for %s", fileBase)
+			}
 
-		fileBase := filepath.Base(requestData.URI)
-		fmt.Fprintln(logger, "createClientHandler: queue", fileBase, len(messages[fileBase]))
-
-		select {
-		case messages[fileBase] <- violations:
-		case <-time.After(1 * time.Second):
-			t.Fatalf("timeout writing to messages channel for %s", fileBase)
-		}
-
-		return struct{}{}, nil
+			return struct{}{}, nil
+		})
 	}
 }
 
 func createMessageChannels(files map[string]string) map[string]chan []string {
 	messages := make(map[string]chan []string)
 	for _, file := range util.Keys(files) {
-		messages[file] = make(chan []string, 10)
+		messages[filepath.Base(file)] = make(chan []string, 10)
 	}
 
 	return messages
