@@ -5,40 +5,40 @@ import (
 	"embed"
 	"fmt"
 	"html/template"
-	"io"
 	"net"
 	"net/http"
+	"net/http/pprof"
+	"os"
 	"strings"
 
 	"github.com/arl/statsviz"
 
-	"github.com/styrainc/regal/internal/explorer"
-	"github.com/styrainc/regal/internal/lsp/cache"
-	"github.com/styrainc/regal/internal/lsp/clients"
-	"github.com/styrainc/regal/internal/lsp/log"
-	"github.com/styrainc/regal/internal/util"
-
-	_ "net/http/pprof" //nolint:gosec
+	"github.com/open-policy-agent/regal/internal/explorer"
+	"github.com/open-policy-agent/regal/internal/lsp/cache"
+	"github.com/open-policy-agent/regal/internal/lsp/clients"
+	"github.com/open-policy-agent/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/internal/util"
 )
 
 const mainTemplate = "main.tpl"
 
-//go:embed assets/*
-var assets embed.FS
-
-var tpl = template.Must(template.New("main.tpl").ParseFS(assets, "assets/main.tpl"))
+var (
+	//go:embed assets/*
+	assets         embed.FS
+	tpl            = template.Must(template.New(mainTemplate).ParseFS(assets, "assets/main.tpl"))
+	pprofEndpoints = os.Getenv("REGAL_DEBUG") != "" || os.Getenv("REGAL_DEBUG_PPROF") != ""
+)
 
 type Server struct {
 	cache        *cache.Cache
-	logWriter    io.Writer
-	logLevel     log.Level
+	log          *log.Logger
 	workspaceURI string
 	baseURL      string
 	client       clients.Identifier
 }
 
-func NewServer(cache *cache.Cache, logWriter io.Writer, level log.Level) *Server {
-	return &Server{cache: cache, logWriter: logWriter, logLevel: level}
+func NewServer(cache *cache.Cache, logger *log.Logger) *Server {
+	return &Server{cache: cache, log: logger}
 }
 
 func (s *Server) SetWorkspaceURI(uri string) {
@@ -74,9 +74,8 @@ type stringResult struct {
 func (s *Server) Start(_ context.Context) {
 	mux := http.NewServeMux()
 
-	err := statsviz.Register(mux)
-	if err != nil {
-		s.log(log.LevelMessage, fmt.Sprintf("failed to register statsviz handler: %v", err))
+	if err := statsviz.Register(mux); err != nil {
+		s.log.Message("failed to register statsviz handler: %v", err)
 	}
 
 	mux.HandleFunc("GET /explorer/", func(w http.ResponseWriter, r *http.Request) {
@@ -99,10 +98,7 @@ func (s *Server) Start(_ context.Context) {
 		}
 
 		cs := explorer.CompilerStages(path, policy, enableStrict, enableAnnotationProcessing, enablePrint)
-		st := state{
-			Code: policy,
-		}
-		st.Result = make([]stringResult, len(cs)+1)
+		st := state{Code: policy, Result: make([]stringResult, len(cs)+1)}
 
 		for i := range cs {
 			st.Result[i].Stage = cs[i].Stage
@@ -144,56 +140,60 @@ func (s *Server) Start(_ context.Context) {
 
 	mux.Handle("/assets/", http.FileServer(http.FS(assets)))
 
-	// pprof handlers
-	mux.HandleFunc("/debug/pprof/", http.DefaultServeMux.ServeHTTP)
-	mux.HandleFunc("/debug/pprof/profile", http.DefaultServeMux.ServeHTTP)
-	mux.HandleFunc("/debug/pprof/heap", http.DefaultServeMux.ServeHTTP)
+	if pprofEndpoints {
+		mux.HandleFunc("GET /debug/pprof/", pprof.Index)
+		mux.Handle("GET /debug/pprof/allocs", pprof.Handler("allocs"))
+		mux.Handle("GET /debug/pprof/block", pprof.Handler("block"))
+		mux.Handle("GET /debug/pprof/heap", pprof.Handler("heap"))
+		mux.Handle("GET /debug/pprof/mutex", pprof.Handler("mutex"))
+		mux.HandleFunc("GET /debug/pprof/cmdline", pprof.Cmdline)
+		mux.HandleFunc("GET /debug/pprof/profile", pprof.Profile)
+		mux.HandleFunc("GET /debug/pprof/symbol", pprof.Symbol)
+		mux.HandleFunc("GET /debug/pprof/trace", pprof.Trace)
+	}
 
 	// root handler for those looking for what the server is
 	mux.HandleFunc("/", func(w http.ResponseWriter, _ *http.Request) {
-		_, err := w.Write([]byte(`
+		body := `
 <h1>Regal Language Server</h1>
-<ul>
-<li><a href="/debug/pprof/">pprof</a></li>
+<ul>`
+
+		if pprofEndpoints {
+			body += `<li><a href="/debug/pprof/">pprof</a></li>
 <li><a href="/debug/statsviz">statsviz</a></li>
-</ul>`))
-		if err != nil {
-			s.log(log.LevelMessage, fmt.Sprintf("failed to write response: %v", err))
+</ul>`
+		} else {
+			body += `Start server with REGAL_DEBUG or REGAL_DEBUG_PPROF set to enable pprof endpoints`
+		}
+
+		if _, err := w.Write([]byte(body)); err != nil {
+			s.log.Message("failed to write response: %v", err)
 		}
 	})
 
 	freePort, err := util.FreePort(5052, 5053, 5054)
 	if err != nil {
-		s.log(log.LevelMessage, "preferred web server ports are not available, using random port")
+		s.log.Message("preferred web server ports are not available, using random port")
 
 		freePort = 0
 	}
 
-	listener, err := net.Listen("tcp", fmt.Sprintf("localhost:%d", freePort))
+	var lc net.ListenConfig
+
+	//nolint:contextcheck
+	listener, err := lc.Listen(context.Background(), "tcp", fmt.Sprintf("localhost:%d", freePort))
 	if err != nil {
-		s.log(log.LevelMessage, fmt.Sprintf("failed to start web server: %v", err))
+		s.log.Message("failed to start web server: %v", err)
 
 		return
 	}
 
 	s.baseURL = "http://" + listener.Addr().String()
 
-	s.log(log.LevelMessage, "starting web server for docs on "+s.baseURL)
+	s.log.Message("starting web server for docs on %s", s.baseURL)
 
 	//nolint:gosec // this is a local server, no timeouts needed
-	err = http.Serve(listener, mux)
-	if err != nil {
-		s.log(log.LevelMessage, fmt.Sprintf("failed to serve web server: %v", err))
-	}
-}
-
-//nolint:unparam
-func (s *Server) log(level log.Level, message string) {
-	if !s.logLevel.ShouldLog(level) {
-		return
-	}
-
-	if s.logWriter != nil {
-		fmt.Fprintln(s.logWriter, message)
+	if err = http.Serve(listener, mux); err != nil {
+		s.log.Message("failed to serve web server: %v", err)
 	}
 }
