@@ -1,35 +1,28 @@
 package config
 
 import (
-	"errors"
 	"fmt"
-	"strings"
 
 	"dario.cat/mergo"
 
 	"github.com/open-policy-agent/opa/v1/bundle"
 
-	"github.com/styrainc/regal/internal/util"
+	"github.com/open-policy-agent/regal/internal/util"
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 )
 
-func LoadConfigWithDefaultsFromBundle(regalBundle *bundle.Bundle, userConfig *Config) (Config, error) {
-	path := []string{"regal", "config", "provided"}
-
-	bundled, err := util.SearchMap(regalBundle.Data, path)
-	if err != nil {
-		return Config{}, fmt.Errorf("config path not found %s: %w", strings.Join(path, "."), err)
-	}
+// WithDefaultsFromBundle returns a complete configuration based on the default
+// (embedded) configuration and (optionally) a user-provided configuration. Panics if the
+// embedded configuration can't be read, as that is a hard dependency.
+func WithDefaultsFromBundle(regalBundle *bundle.Bundle, userConfig *Config) (Config, error) {
+	bundled := util.Must(util.SearchMap(regalBundle.Data, "regal", "config", "provided"))
 
 	bundledConf, ok := bundled.(map[string]any)
 	if !ok {
-		return Config{}, errors.New("expected 'rules' of object type")
-	}
-
-	defaultConfig, err := FromMap(bundledConf)
-	if err != nil {
-		return Config{}, fmt.Errorf("failed to convert config from map: %w", err)
+		panic("expected 'rules' of object type in default configuration")
 	}
 
+	defaultConfig := util.Must(encoding.JSONRoundTripTo[Config](bundledConf))
 	if userConfig == nil {
 		defaultConfig.Capabilities = CapabilitiesForThisVersion()
 
@@ -38,7 +31,7 @@ func LoadConfigWithDefaultsFromBundle(regalBundle *bundle.Bundle, userConfig *Co
 
 	providedRuleLevels := providedConfLevels(&defaultConfig)
 
-	if err = mergo.Merge(&defaultConfig, userConfig, mergo.WithOverride); err != nil {
+	if err := mergo.Merge(&defaultConfig, userConfig, mergo.WithOverride); err != nil {
 		return Config{}, fmt.Errorf("failed to merge user config: %w", err)
 	}
 
@@ -58,9 +51,10 @@ func LoadConfigWithDefaultsFromBundle(regalBundle *bundle.Bundle, userConfig *Co
 func extractUserRuleLevels(userConfig *Config, mergedConf *Config, providedRuleLevels map[string]string) {
 	for categoryName, rulesByCategory := range mergedConf.Rules {
 		for ruleName, rule := range rulesByCategory {
-			var providedLevel string
-
-			var ok bool
+			var (
+				providedLevel             string
+				ok, userHasConfiguredRule bool
+			)
 
 			if providedLevel, ok = providedRuleLevels[ruleName]; !ok {
 				continue
@@ -69,8 +63,6 @@ func extractUserRuleLevels(userConfig *Config, mergedConf *Config, providedRuleL
 			// use the level from the provided configuration as the fallback
 			selectedRuleLevel := providedLevel
 
-			var userHasConfiguredRule bool
-
 			if _, ok := userConfig.Rules[categoryName]; ok {
 				_, userHasConfiguredRule = userConfig.Rules[categoryName][ruleName]
 			}
