@@ -14,19 +14,22 @@ import (
 	"github.com/open-policy-agent/opa/v1/ast"
 	"github.com/open-policy-agent/opa/v1/bundle"
 
-	"github.com/styrainc/regal/internal/capabilities"
-	rio "github.com/styrainc/regal/internal/io"
-	"github.com/styrainc/regal/internal/util"
-
-	"github.com/styrainc/roast/pkg/encoding"
-	rutil "github.com/styrainc/roast/pkg/util"
+	"github.com/open-policy-agent/regal/internal/capabilities"
+	rio "github.com/open-policy-agent/regal/internal/io"
+	"github.com/open-policy-agent/regal/internal/io/files"
+	"github.com/open-policy-agent/regal/internal/io/files/filter"
+	"github.com/open-policy-agent/regal/internal/util"
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 )
 
 const (
-	capabilitiesEngineOPA  = "opa"
-	capabilitiesEngineEOPA = "eopa"
-	keyIgnore              = "ignore"
-	keyLevel               = "level"
+	capabilitiesEngineOPA    = "opa"
+	capabilitiesEngineEOPA   = "eopa"
+	keyIgnore                = "ignore"
+	keyLevel                 = "level"
+	regalDirName             = ".regal"
+	configFileName           = "config.yaml"
+	standaloneConfigFileName = ".regal.yaml"
 )
 
 type Config struct {
@@ -78,20 +81,6 @@ type RemoteFeatures struct {
 	CheckVersion bool `json:"check-version,omitempty" yaml:"check-version,omitempty"`
 }
 
-func (d *Default) mapToConfig(result any) error {
-	resultMap, ok := result.(map[string]any)
-	if !ok {
-		return errors.New("result was not a map")
-	}
-
-	level, ok := resultMap[keyLevel].(string)
-	if ok {
-		d.Level = level
-	}
-
-	return nil
-}
-
 type Ignore struct {
 	Files []string `json:"files,omitempty" yaml:"files,omitempty"`
 }
@@ -119,25 +108,29 @@ type Builtin struct {
 	Decl Decl `json:"decl" yaml:"decl"`
 }
 
-const (
-	regalDirName             = ".regal"
-	configFileName           = "config.yaml"
-	standaloneConfigFileName = ".regal.yaml"
-)
-
-func FromPath(path string) (Config, error) {
-	file, err := os.Open(path)
-	if err != nil {
-		return Config{}, fmt.Errorf("failed to open config file: %w", err)
+func (d *Default) mapToConfig(result any) error {
+	resultMap, ok := result.(map[string]any)
+	if !ok {
+		return errors.New("result was not a map")
 	}
 
-	defer file.Close()
+	level, ok := resultMap[keyLevel].(string)
+	if ok {
+		d.Level = level
+	}
 
+	return nil
+}
+
+func FromPath(path string) (Config, error) {
+	return util.Wrap(util.WithOpen(path, FromFile))("failed to open config file")
+}
+
+func FromFile(file *os.File) (Config, error) {
 	conf := Config{}
+	err := yaml.NewDecoder(file).Decode(&conf)
 
-	err = yaml.NewDecoder(file).Decode(&conf)
-
-	return conf, err //nolint:wrapcheck
+	return conf, err
 }
 
 // FindConfig attempts to find either the .regal directory or .regal.yaml
@@ -167,10 +160,9 @@ func FindConfig(path string) (*os.File, error) {
 		return regalConfigFile, nil
 	}
 
-	// if there is a .regal directory, when a config file is expected to be
-	// found inside.
+	// if there is a .regal directory, a config file is expected to be found inside.
 	if regalDirError == nil {
-		expectedConfigFilePath := filepath.Join(regalDir.Name(), rio.PathSeparator, configFileName)
+		expectedConfigFilePath := filepath.Join(regalDir.Name(), configFileName)
 
 		_, err := os.Stat(expectedConfigFilePath)
 		if err != nil && os.IsNotExist(err) {
@@ -179,7 +171,7 @@ func FindConfig(path string) (*os.File, error) {
 			return nil, fmt.Errorf("failed to stat .regal config file: %w", err)
 		}
 
-		return os.Open(expectedConfigFilePath) //nolint:wrapcheck
+		return os.Open(expectedConfigFilePath)
 	}
 
 	// regalConfigFileError is nil at this point, so we can return the file
@@ -188,14 +180,9 @@ func FindConfig(path string) (*os.File, error) {
 
 // findUpwards searches for a file or directory matching the given name,
 // starting from the provided path and moving upwards.
-func findUpwards(path, name string, expectDir bool) (*os.File, error) {
-	finfo, err := os.Stat(path)
-	if err != nil {
-		return nil, fmt.Errorf("failed to stat path %v: %w", path, err)
-	}
-
+func findUpwards(path, name string, expectDir bool) (string, error) {
 	dir := path
-	if !finfo.IsDir() {
+	if !rio.IsDir(path) {
 		dir = filepath.Dir(path)
 	}
 
@@ -205,47 +192,56 @@ func findUpwards(path, name string, expectDir bool) (*os.File, error) {
 	for {
 		var searchPath string
 		if volume == "" {
-			searchPath = filepath.Join(rio.PathSeparator, dir, name)
+			searchPath = filepath.Join(string(os.PathSeparator), dir, name)
 		} else {
 			searchPath = filepath.Join(dir, name)
 		}
 
-		file, err := os.Open(searchPath)
-		if err == nil {
-			fileInfo, err := file.Stat()
-			if err == nil && fileInfo.IsDir() == expectDir {
-				return file, nil
-			}
+		if fileInfo, err := os.Stat(searchPath); err == nil && fileInfo.IsDir() == expectDir {
+			return searchPath, nil
 		}
 
-		if searchPath == volume+rio.PathSeparator+name {
-			// Stop traversing at the root path
-			return nil, fmt.Errorf("can't traverse past root directory %w", err)
+		if searchPath == volume+string(os.PathSeparator)+name {
+			return "", errors.New("can't traverse past root directory")
 		}
 
 		// Move up one level in the directory tree
-		parts := strings.Split(dir, rio.PathSeparator)
+		parts := strings.Split(dir, string(os.PathSeparator))
 		if len(parts) < 2 {
-			return nil, errors.New("stopping as dir is root directory")
+			return "", errors.New("stopping as dir is root directory")
 		}
 
 		parts = parts[:len(parts)-1]
 		if parts[0] == volume {
-			parts[0] = volume + rio.PathSeparator
+			parts[0] = volume + string(os.PathSeparator)
 		}
 
 		dir = filepath.Join(parts...)
 	}
 }
 
+func findFileUpwards(path, name string, expectDir bool) (*os.File, error) {
+	dir, err := findUpwards(path, name, expectDir)
+	if err != nil {
+		return nil, fmt.Errorf("failed to find .regal directory: %w", err)
+	}
+
+	return util.Wrap(os.Open(dir))("failed to open .regal directory")
+}
+
+// FindRegalDirectoryPath searches for a .regal directory upwards from the provided path.
+func FindRegalDirectoryPath(path string) (string, error) {
+	return findUpwards(path, regalDirName, true)
+}
+
 // FindRegalDirectory searches for a .regal directory upwards from the provided path.
 func FindRegalDirectory(path string) (*os.File, error) {
-	return findUpwards(path, regalDirName, true)
+	return findFileUpwards(path, regalDirName, true)
 }
 
 // FindRegalConfigFile searches for a .regal.yaml config file upwards from the provided path.
 func FindRegalConfigFile(path string) (*os.File, error) {
-	return findUpwards(path, standaloneConfigFileName, false)
+	return findFileUpwards(path, standaloneConfigFileName, false)
 }
 
 // FindBundleRootDirectories finds all bundle root directories from the provided path,
@@ -283,24 +279,12 @@ func FindBundleRootDirectories(path string) ([]string, error) {
 	}
 
 	// This will traverse the tree **downwards** searching for .regal directories
-	// Not using rio.WalkFiles here as we're specifically looking for directories
-	if err := filepath.WalkDir(path, func(path string, info os.DirEntry, err error) error {
-		if err != nil {
-			return fmt.Errorf("failed to walk path: %w", err)
-		}
-
-		if info.IsDir() && info.Name() == regalDirName {
+	if err := files.NewWalker(path).WithSkipFunc(filter.DefaultSkipDirectories).Walk(func(path string) error {
+		if filepath.Dir(path) == regalDirName {
 			// Opening files as part of walking is generally not a good idea...
 			// but I think we can assume the number of .regal directories in a project
 			// is limited to a reasonable number.
-			rd, err := os.Open(path)
-			if err != nil {
-				return fmt.Errorf("failed to open .regal directory: %w", err)
-			}
-
-			defer rd.Close()
-
-			roots, err := rootsFromRegalConfigDirOrFile(rd)
+			roots, err := util.WithOpen(path, rootsFromRegalConfigDirOrFile)
 			if err != nil {
 				return fmt.Errorf("failed to get roots from .regal directory: %w", err)
 			}
@@ -309,7 +293,7 @@ func FindBundleRootDirectories(path string) ([]string, error) {
 		}
 
 		// check for .manifest directories as part of the same walk
-		if !info.IsDir() && info.Name() == ".manifest" {
+		if filepath.Base(path) == ".manifest" {
 			foundBundleRoots = append(foundBundleRoots, filepath.Dir(path))
 		}
 
@@ -323,6 +307,7 @@ func FindBundleRootDirectories(path string) ([]string, error) {
 	return slices.Compact(foundBundleRoots), nil
 }
 
+// TODO: this doesn't properly handle .regal.yaml??
 func rootsFromRegalConfigDirOrFile(file *os.File) ([]string, error) {
 	defer file.Close()
 
@@ -331,46 +316,30 @@ func rootsFromRegalConfigDirOrFile(file *os.File) ([]string, error) {
 		return nil, fmt.Errorf("failed to stat file: %w", err)
 	}
 
-	if (fileInfo.IsDir() && filepath.Base(file.Name()) != ".regal") ||
-		(!fileInfo.IsDir() && filepath.Base(file.Name()) != ".regal.yaml") {
-		return nil, fmt.Errorf(
-			"expected a directory named '.regal' or a file named '.regal.yaml', got '%s'",
-			filepath.Base(file.Name()),
-		)
+	parent, filename := filepath.Split(file.Name())
+	if (fileInfo.IsDir() && filename != ".regal") ||
+		(!fileInfo.IsDir() && filename != ".regal.yaml") {
+		return nil, fmt.Errorf("expected a directory named '.regal' or a file named '.regal.yaml', got '%s'", filename)
 	}
 
-	parent := filepath.Dir(file.Name())
+	parent = filepath.Clean(parent)
+
+	configFilePath := file.Name()
+	if fileInfo.IsDir() {
+		configFilePath = filepath.Join(configFilePath, "config.yaml")
+	}
 
 	foundBundleRoots := []string{parent}
 
-	var configFilePath string
-
-	if fileInfo.IsDir() {
-		configFilePath = filepath.Join(file.Name(), "config.yaml")
-	} else {
-		configFilePath = file.Name()
-	}
-
-	fileContent, err := os.ReadFile(configFilePath)
-	if err == nil {
-		var conf Config
-		if err = yaml.Unmarshal(fileContent, &conf); err != nil {
-			return nil, fmt.Errorf("failed to unmarshal config file: %w", err)
-		}
-
-		if conf.Project != nil && conf.Project.Roots != nil {
-			for _, root := range *conf.Project.Roots {
-				foundBundleRoots = append(foundBundleRoots, filepath.Join(parent, root.Path))
-			}
+	if conf, err := FromPath(configFilePath); err == nil && conf.Project != nil && conf.Project.Roots != nil {
+		for _, root := range *conf.Project.Roots {
+			foundBundleRoots = append(foundBundleRoots, filepath.Join(parent, root.Path))
 		}
 	}
 
 	// Include the "rules" directory when loading from a .regal dir
 	if fileInfo.IsDir() {
-		customDir := filepath.Join(file.Name(), "rules")
-
-		info, err := os.Stat(customDir)
-		if err == nil && info.IsDir() {
+		if customDir := filepath.Join(file.Name(), "rules"); rio.IsDir(customDir) {
 			foundBundleRoots = append(foundBundleRoots, customDir)
 		}
 	}
@@ -381,19 +350,7 @@ func rootsFromRegalConfigDirOrFile(file *os.File) ([]string, error) {
 		return nil, fmt.Errorf("failed while looking for manifest locations: %w", err)
 	}
 
-	foundBundleRoots = append(foundBundleRoots, util.Map(manifestRoots, util.FilepathJoiner(parent))...)
-
-	return foundBundleRoots, nil
-}
-
-func FromMap(confMap map[string]any) (Config, error) {
-	var conf Config
-
-	if err := encoding.JSONRoundTrip(confMap, &conf); err != nil {
-		return conf, fmt.Errorf("failed to convert config map to config struct: %w", err)
-	}
-
-	return conf, nil
+	return append(foundBundleRoots, util.Map(manifestRoots, util.FilepathJoiner(parent))...), nil
 }
 
 // AllRegoVersions returns a map of all Rego versions found in the provided config and .manifest files,
@@ -401,7 +358,6 @@ func FromMap(confMap map[string]any) (Config, error) {
 // than .manifest files.
 func AllRegoVersions(root string, conf *Config) (map[string]ast.RegoVersion, error) {
 	versionsMap := make(map[string]ast.RegoVersion)
-
 	if conf == nil {
 		return versionsMap, nil
 	}
@@ -412,16 +368,12 @@ func AllRegoVersions(root string, conf *Config) (map[string]ast.RegoVersion, err
 	}
 
 	for _, dir := range manifestLocations {
-		manifestPath := filepath.Join(root, dir, ".manifest")
-
-		f, err := os.ReadFile(manifestPath)
+		f, err := os.ReadFile(filepath.Join(root, dir, ".manifest"))
 		if err != nil {
 			return nil, fmt.Errorf("failed to read manifest file: %w", err)
 		}
 
-		var manifest bundle.Manifest
-
-		err = encoding.JSON().Unmarshal(f, &manifest)
+		manifest, err := encoding.JSONUnmarshalTo[bundle.Manifest](f)
 		if err != nil {
 			return nil, fmt.Errorf("failed to unmarshal manifest file: %w", err)
 		}
@@ -467,9 +419,8 @@ func regoVersionFromConfigValue(version *int) ast.RegoVersion {
 }
 
 func (config Config) MarshalYAML() (any, error) {
-	var unstructuredConfig map[string]any
-
-	if err := encoding.JSONRoundTrip(config, &unstructuredConfig); err != nil {
+	unstructuredConfig, err := encoding.JSONRoundTripTo[map[string]any](config)
+	if err != nil {
 		return nil, fmt.Errorf("failed to created unstructured config: %w", err)
 	}
 
@@ -502,6 +453,10 @@ func (config Config) MarshalYAML() (any, error) {
 		delete(unstructuredConfig, keyIgnore)
 	}
 
+	if config.CapabilitiesURL == "" || config.CapabilitiesURL == capabilities.DefaultURL {
+		delete(unstructuredConfig, "capabilities_url")
+	}
+
 	return unstructuredConfig, nil
 }
 
@@ -531,7 +486,7 @@ type marshallingIntermediary struct {
 	Ignore   Ignore `yaml:"ignore"`
 	Features struct {
 		RemoteFeatures struct {
-			CheckVersion bool `yaml:"check_version"`
+			CheckVersion bool `yaml:"check-version"`
 		} `yaml:"remote"`
 	} `yaml:"features"`
 }
@@ -555,7 +510,7 @@ func (p *Project) UnmarshalYAML(value *yaml.Node) error {
 		}
 	}
 
-	return encoding.JSONRoundTrip(result, p) //nolint:wrapcheck
+	return encoding.JSONRoundTrip(result, p)
 }
 
 func (config *Config) UnmarshalYAML(value *yaml.Node) error {
@@ -640,7 +595,7 @@ func (config *Config) UnmarshalYAML(value *yaml.Node) error {
 	}
 
 	if capabilitiesEngine == "" && capabilitiesFile == "" && capabilitiesURL == "" {
-		capabilitiesURL = "regal:///capabilities/default"
+		capabilitiesURL = capabilities.DefaultURL
 	}
 
 	opaCaps, err := capabilities.Lookup(context.Background(), capabilitiesURL)
@@ -648,13 +603,11 @@ func (config *Config) UnmarshalYAML(value *yaml.Node) error {
 		return fmt.Errorf("failed to load capabilities: %w", err)
 	}
 
-	config.Capabilities = fromOPACapabilities(opaCaps)
-
 	// This is used in the LSP to load the OPA capabilities, since the
 	// capabilities version in the user-facing config does not contain all
 	// of the information that the LSP needs.
 	config.CapabilitiesURL = capabilitiesURL
-
+	config.Capabilities = fromOPACapabilities(opaCaps)
 	config.Project = result.Project
 
 	// remove any builtins referenced in the minus config
@@ -669,11 +622,7 @@ func (config *Config) UnmarshalYAML(value *yaml.Node) error {
 
 	// feature defaults
 	if result.Features.RemoteFeatures.CheckVersion {
-		config.Features = &Features{
-			Remote: &RemoteFeatures{
-				CheckVersion: true,
-			},
-		}
+		config.Features = &Features{Remote: &RemoteFeatures{CheckVersion: true}}
 	}
 
 	return nil
@@ -723,8 +672,7 @@ func extractRules(config *Config, result *marshallingIntermediary) error {
 func extractDefaults(c *Config, result *marshallingIntermediary) error {
 	c.Defaults.Categories = make(map[string]Default)
 
-	rawGlobalDefault, ok := result.Rules["default"]
-	if ok {
+	if rawGlobalDefault, ok := result.Rules["default"]; ok {
 		if err := c.Defaults.Global.mapToConfig(rawGlobalDefault); err != nil {
 			return fmt.Errorf("unmarshalling global defaults failed: %w", err)
 		}
@@ -775,10 +723,7 @@ func fromOPABuiltin(builtin ast.Builtin) *Builtin {
 }
 
 func fromOPACapabilities(capabilities *ast.Capabilities) *Capabilities {
-	var result Capabilities
-
-	result.Builtins = make(map[string]*Builtin, len(capabilities.Builtins))
-
+	result := Capabilities{Builtins: make(map[string]*Builtin, len(capabilities.Builtins))}
 	for _, builtin := range capabilities.Builtins {
 		result.Builtins[builtin.Name] = fromOPABuiltin(*builtin)
 	}
@@ -815,12 +760,12 @@ func (rule *Rule) MarshalJSON() ([]byte, error) {
 		return nil, fmt.Errorf("marshalling rule failed %w", err)
 	}
 
-	return encoding.JSON().Marshal(&result) //nolint:wrapcheck
+	return encoding.JSON().Marshal(&result)
 }
 
 func (rule *Rule) UnmarshalJSON(data []byte) error {
-	var result map[string]any
-	if err := encoding.JSON().Unmarshal(data, &result); err != nil {
+	result, err := encoding.JSONUnmarshalTo[map[string]any](data)
+	if err != nil {
 		return fmt.Errorf("unmarshalling rule failed %w", err)
 	}
 
@@ -828,8 +773,7 @@ func (rule *Rule) UnmarshalJSON(data []byte) error {
 }
 
 func (rule *Rule) MarshalYAML() (any, error) {
-	result := make(map[string]any)
-	result[keyLevel] = rule.Level
+	result := map[string]any{keyLevel: rule.Level}
 
 	if rule.Ignore != nil && len(rule.Ignore.Files) != 0 {
 		result[keyIgnore] = rule.Ignore
@@ -868,9 +812,8 @@ func (rule *Rule) mapToConfig(result any) error {
 	}
 
 	if ignore, ok := ruleMap[keyIgnore]; ok {
-		var dst Ignore
-
-		if err := encoding.JSONRoundTrip(ignore, &dst); err != nil {
+		dst, err := encoding.JSONRoundTripTo[Ignore](ignore)
+		if err != nil {
 			return fmt.Errorf("unmarshalling rule ignore failed: %w", err)
 		}
 
@@ -894,20 +837,19 @@ func GetPotentialRoots(paths ...string) ([]string, error) {
 		abs := path
 
 		if !filepath.IsAbs(abs) {
-			abs, err = filepath.Abs(path)
-			if err != nil {
+			if abs, err = filepath.Abs(path); err != nil {
 				return nil, fmt.Errorf("failed to get absolute path for %s: %w", path, err)
 			}
 		}
 
-		if isDir(abs) {
+		if rio.IsDir(abs) {
 			absDirPaths[i] = abs
 		} else {
 			absDirPaths[i] = filepath.Dir(abs)
 		}
 	}
 
-	dirMap := rutil.NewSet[string]()
+	dirMap := util.NewSet[string]()
 
 	for _, dir := range absDirPaths {
 		brds, err := FindBundleRootDirectories(dir)
@@ -924,12 +866,3 @@ func GetPotentialRoots(paths ...string) ([]string, error) {
 
 	return dirMap.Items(), nil
 }
-
-func isDir(path string) bool {
-	info, err := os.Stat(path)
-	if err != nil {
-		return false
-	}
-
-	return info.IsDir()
-}
