@@ -4,20 +4,17 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/styrainc/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/internal/testutil"
 )
 
 func TestFromFS(t *testing.T) {
 	t.Parallel()
 
-	tempDir := testutil.TempDirectoryOf(t, map[string]string{
-		"foo/bar/baz": "bar",
-		"bar/foo":     "baz",
-	})
-	fp := testutil.Must(NewInMemoryFileProviderFromFS([]string{
+	tempDir := testutil.TempDirectoryOf(t, map[string]string{"foo/bar/baz": "bar", "bar/foo": "baz"})
+	fp := testutil.Must(NewInMemoryFileProviderFromFS(
 		filepath.Join(tempDir, "foo", "bar", "baz"),
 		filepath.Join(tempDir, "bar", "foo"),
-	}...))(t)
+	))(t)
 
 	if fc, err := fp.Get(filepath.Join(tempDir, "foo", "bar", "baz")); err != nil || fc != "bar" {
 		t.Fatalf("expected %s, got %s", "bar", fc)
@@ -27,19 +24,8 @@ func TestFromFS(t *testing.T) {
 func TestRenameConflict(t *testing.T) {
 	t.Parallel()
 
-	fp := NewInMemoryFileProvider(map[string]string{
-		"/foo/bar/baz": "bar",
-		"/bar/foo":     "baz",
-	})
-
-	err := fp.Rename("/foo/bar/baz", "/bar/foo")
-	if err == nil {
-		t.Fatal("expected error")
-	}
-
+	fp := NewInMemoryFileProvider(map[string]string{"/foo/bar/baz": "bar", "/bar/foo": "baz"})
 	exp := `rename conflict: "/foo/bar/baz" cannot be renamed as the target location "/bar/foo" already exists`
 
-	if got := err.Error(); got != exp {
-		t.Fatalf("expected %s, got %s", exp, got)
-	}
+	testutil.ErrMustContain(fp.Rename("/foo/bar/baz", "/bar/foo"), exp)(t)
 }
