@@ -1,16 +1,17 @@
 package fixer
 
 import (
+	"path/filepath"
 	"slices"
 	"testing"
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/pkg/config"
-	"github.com/styrainc/regal/pkg/fixer/fileprovider"
-	"github.com/styrainc/regal/pkg/fixer/fixes"
-	"github.com/styrainc/regal/pkg/linter"
-	"github.com/styrainc/regal/pkg/report"
+	"github.com/open-policy-agent/regal/pkg/config"
+	"github.com/open-policy-agent/regal/pkg/fixer/fileprovider"
+	"github.com/open-policy-agent/regal/pkg/fixer/fixes"
+	"github.com/open-policy-agent/regal/pkg/linter"
+	"github.com/open-policy-agent/regal/pkg/report"
 )
 
 func TestFixer(t *testing.T) {
@@ -35,16 +36,10 @@ deny = true
 		t.Fatalf("failed to create input: %v", err)
 	}
 
-	l := linter.NewLinter().
-		WithEnableAll(true).
-		WithInputModules(&input)
+	l := linter.NewLinter().WithEnableAll(true).WithInputModules(&input)
 
-	f := NewFixer()
-	f.RegisterFixes(fixes.NewDefaultFixes()...)
-	f.RegisterRoots("/root")
-	f.SetRegoVersionsMap(map[string]ast.RegoVersion{
-		"/root/main": ast.RegoV1,
-	})
+	f := NewFixer().RegisterFixes(fixes.NewDefaultFixes()...).RegisterRoots("/root").SetRegoVersionsMap(
+		map[string]ast.RegoVersion{"/root/main": ast.RegoV1})
 
 	fixReport, err := f.Fix(t.Context(), &l, memfp)
 	if err != nil {
@@ -124,30 +119,17 @@ func TestFixViolations(t *testing.T) {
 	t.Parallel()
 
 	// targeted specific fix for a given violation
-	violations := []report.Violation{
-		{
-			Title:    "directory-package-mismatch",
-			Location: report.Location{File: "root/main.rego"},
-		},
-	}
+	violations := []report.Violation{{
+		Title:    "directory-package-mismatch",
+		Location: report.Location{File: filepath.FromSlash("root/main.rego")},
+	}}
 
-	policies := map[string]string{
-		"root/main.rego": `package foo.bar
+	memfp := fileprovider.NewInMemoryFileProvider(map[string]string{
+		filepath.FromSlash("root/main.rego"):         "package foo.bar\n\nallow := true\n",
+		filepath.FromSlash("root/foo/bar/main.rego"): "package foo.bar\n\nallow := true\n", // file in correct place
+	})
 
-allow := true
-`,
-		// file in correct place
-		"root/foo/bar/main.rego": `package foo.bar
-
-allow := true
-`,
-	}
-
-	memfp := fileprovider.NewInMemoryFileProvider(policies)
-
-	f := NewFixer()
-	f.SetOnConflictOperation(OnConflictRename)
-	f.RegisterFixes(fixes.NewDefaultFixes()...)
+	f := NewFixer().SetOnConflictOperation(OnConflictRename).RegisterFixes(fixes.NewDefaultFixes()...)
 
 	fixReport, err := f.FixViolations(violations, memfp, &config.Config{})
 	if err != nil {
@@ -155,25 +137,14 @@ allow := true
 	}
 
 	expectedFileFixedViolations := map[string][]string{
-		"root/main.rego":           {"directory-package-mismatch"},
-		"root/foo/bar/main_1.rego": {"directory-package-mismatch"},
-		"root/foo/bar/main.rego":   {}, // no fixes
+		filepath.FromSlash("root/main.rego"):           {"directory-package-mismatch"},
+		filepath.FromSlash("root/foo/bar/main_1.rego"): {"directory-package-mismatch"},
+		filepath.FromSlash("root/foo/bar/main.rego"):   {}, // no fixes
 	}
 	expectedFileContents := map[string]string{
-		// old file yet to be deleted
-		"root/main.rego": `package foo.bar
-
-allow := true
-`,
-		"root/foo/bar/main_1.rego": `package foo.bar
-
-allow := true
-`,
-		// file in correct place
-		"root/foo/bar/main.rego": `package foo.bar
-
-allow := true
-`,
+		filepath.FromSlash("root/main.rego"):           "package foo.bar\n\nallow := true\n", // old file yet to be deleted
+		filepath.FromSlash("root/foo/bar/main_1.rego"): "package foo.bar\n\nallow := true\n",
+		filepath.FromSlash("root/foo/bar/main.rego"):   "package foo.bar\n\nallow := true\n", // file in correct place
 	}
 
 	if got, exp := fixReport.TotalFixes(), uint(2); got != exp {
@@ -198,17 +169,12 @@ allow := true
 		}
 
 		if content != expectedContent {
-			t.Fatalf("unexpected content for %s:\ngot:\n%s---\nexpected:\n%s---",
-				file,
-				content,
-				expectedContent)
+			t.Fatalf("unexpected content for %s:\ngot:\n%s---\nexpected:\n%s---", file, content, expectedContent)
 		}
 
-		fxs := fixReport.FixesForFile(file)
-
 		// check that the fixed violations are correct
 		var fixes []string
-		for _, fx := range fxs {
+		for _, fx := range fixReport.FixesForFile(file) {
 			fixes = append(fixes, fx.Title)
 		}
 
