@@ -9,7 +9,7 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/pkg/config"
+	"github.com/open-policy-agent/regal/pkg/config"
 )
 
 type DirectoryPackageMismatch struct{}
@@ -32,7 +32,6 @@ func (d *DirectoryPackageMismatch) Fix(fc *FixCandidate, opts *RuntimeOptions) (
 	}
 
 	rootPath := filepath.Clean(cmp.Or(opts.BaseDir, filepath.Dir(fc.Filename)))
-
 	newPath := filepath.Join(rootPath, pkgPath, filepath.Base(fc.Filename))
 
 	if newPath == fc.Filename {
@@ -53,7 +52,7 @@ func (d *DirectoryPackageMismatch) Fix(fc *FixCandidate, opts *RuntimeOptions) (
 func getPackagePathDirectory(fc *FixCandidate, config *config.Config) (string, error) {
 	module, err := ast.ParseModule(fc.Filename, fc.Contents)
 	if err != nil {
-		return "", err //nolint:wrapcheck
+		return "", err
 	}
 
 	parts := make([]string, len(module.Package.Path)-1)
@@ -78,14 +77,12 @@ func getPackagePathDirectory(fc *FixCandidate, config *config.Config) (string, e
 }
 
 func shouldExcludeTestSuffix(config *config.Config) bool {
-	if config == nil {
-		return true
-	}
-
-	if category, ok := config.Rules["idiomatic"]; ok {
-		if rule, ok := category["directory-package-mismatch"]; ok {
-			if exclude, ok := rule.Extra["exclude-test-suffix"].(bool); ok {
-				return exclude
+	if config != nil {
+		if category, ok := config.Rules["idiomatic"]; ok {
+			if rule, ok := category["directory-package-mismatch"]; ok {
+				if exclude, ok := rule.Extra["exclude-test-suffix"].(bool); ok {
+					return exclude
+				}
 			}
 		}
 	}
