@@ -21,7 +21,6 @@ func (u *NonRawRegexPattern) Fix(fc *FixCandidate, opts *RuntimeOptions) ([]FixR
 	}
 
 	lines := strings.Split(fc.Contents, "\n")
-
 	fileChanged := false
 
 	for _, loc := range opts.Locations {
@@ -58,11 +57,5 @@ func (u *NonRawRegexPattern) Fix(fc *FixCandidate, opts *RuntimeOptions) ([]FixR
 		return []FixResult{}, nil
 	}
 
-	newContents := strings.Join(lines, "\n")
-
-	return []FixResult{{
-		Title:    u.Name(),
-		Root:     opts.BaseDir,
-		Contents: newContents,
-	}}, nil
+	return []FixResult{{Title: u.Name(), Root: opts.BaseDir, Contents: strings.Join(lines, "\n")}}, nil
 }
