@@ -1,11 +1,9 @@
 package fixer
 
 import (
-	"slices"
-
 	"github.com/open-policy-agent/opa/v1/util"
 
-	"github.com/styrainc/regal/pkg/fixer/fixes"
+	"github.com/open-policy-agent/regal/pkg/fixer/fixes"
 )
 
 // Report contains updated file contents and summary information about the fixes that were applied
@@ -56,12 +54,7 @@ func (r *Report) OldPathForFile(newPath string) (string, bool) {
 }
 
 func (r *Report) FixedFiles() []string {
-	fixedFiles := util.Keys(r.fileFixes)
-
-	// sort the files for deterministic output
-	slices.Sort(fixedFiles)
-
-	return fixedFiles
+	return util.KeysSorted(r.fileFixes)
 }
 
 func (r *Report) TotalFixes() uint {
