@@ -9,7 +9,7 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/util"
 
-	"github.com/styrainc/regal/pkg/fixer/fixes"
+	"github.com/open-policy-agent/regal/pkg/fixer/fixes"
 )
 
 // Reporter is responsible for outputting a fix report in a specific format.
@@ -35,9 +35,7 @@ type PrettyReporter struct {
 }
 
 func NewPrettyReporter(outputWriter io.Writer) *PrettyReporter {
-	return &PrettyReporter{
-		outputWriter: outputWriter,
-	}
+	return &PrettyReporter{outputWriter: outputWriter}
 }
 
 func (r *PrettyReporter) SetDryRun(dryRun bool) {
@@ -45,8 +43,7 @@ func (r *PrettyReporter) SetDryRun(dryRun bool) {
 }
 
 func (r *PrettyReporter) ReportConflicts(fixReport *Report) error {
-	roots := util.Keys(fixReport.conflictsSourceFile)
-	slices.Sort(roots)
+	roots := util.KeysSorted(fixReport.conflictsSourceFile)
 
 	if len(roots) > 0 {
 		fmt.Fprintln(r.outputWriter, "Source file conflicts:")
@@ -61,8 +58,7 @@ func (r *PrettyReporter) ReportConflicts(fixReport *Report) error {
 				continue
 			}
 
-			conflictingFiles := util.Keys(cs)
-			slices.Sort(conflictingFiles)
+			conflictingFiles := util.KeysSorted(cs)
 
 			fmt.Fprintln(r.outputWriter, "In project root:", rootKey)
 
@@ -79,9 +75,7 @@ func (r *PrettyReporter) ReportConflicts(fixReport *Report) error {
 		}
 	}
 
-	roots = util.Keys(fixReport.conflictsManyToOne)
-	slices.Sort(roots)
-
+	roots = util.KeysSorted(fixReport.conflictsManyToOne)
 	if len(roots) > 0 {
 		if len(fixReport.conflictsSourceFile) > 0 {
 			fmt.Fprintln(r.outputWriter)
@@ -99,8 +93,7 @@ func (r *PrettyReporter) ReportConflicts(fixReport *Report) error {
 				continue
 			}
 
-			conflictingFiles := util.Keys(cs)
-			slices.Sort(conflictingFiles)
+			conflictingFiles := util.KeysSorted(cs)
 
 			fmt.Fprintln(r.outputWriter, "In project root:", rootKey)
 
@@ -156,19 +149,14 @@ func (r *PrettyReporter) Report(fixReport *Report) error {
 
 	i := 0
 
-	rootsSorted := util.Keys(byRoot)
-
-	slices.Sort(rootsSorted)
-
-	for _, root := range rootsSorted {
+	for _, root := range util.KeysSorted(byRoot) {
 		if i > 0 {
 			fmt.Fprintln(r.outputWriter)
 		}
 
 		fixesByFile := byRoot[root]
-		files := util.Keys(fixesByFile)
+		files := util.KeysSorted(fixesByFile)
 
-		slices.Sort(files)
 		fmt.Fprintf(r.outputWriter, "In project root: %s\n", root)
 
 		for _, file := range files {
