@@ -25,19 +25,16 @@ import (
 	"github.com/open-policy-agent/opa/v1/topdown/print"
 	outil "github.com/open-policy-agent/opa/v1/util"
 
-	rbundle "github.com/styrainc/regal/bundle"
-	rio "github.com/styrainc/regal/internal/io"
-	regalmetrics "github.com/styrainc/regal/internal/metrics"
-	"github.com/styrainc/regal/internal/util"
-	"github.com/styrainc/regal/pkg/builtins"
-	"github.com/styrainc/regal/pkg/config"
-	"github.com/styrainc/regal/pkg/report"
-	"github.com/styrainc/regal/pkg/rules"
-
-	"github.com/styrainc/roast/pkg/encoding"
-	"github.com/styrainc/roast/pkg/rast"
-	"github.com/styrainc/roast/pkg/transform"
-	rutil "github.com/styrainc/roast/pkg/util"
+	rbundle "github.com/open-policy-agent/regal/bundle"
+	rio "github.com/open-policy-agent/regal/internal/io"
+	regalmetrics "github.com/open-policy-agent/regal/internal/metrics"
+	"github.com/open-policy-agent/regal/internal/util"
+	"github.com/open-policy-agent/regal/pkg/builtins"
+	"github.com/open-policy-agent/regal/pkg/config"
+	"github.com/open-policy-agent/regal/pkg/report"
+	"github.com/open-policy-agent/regal/pkg/roast/rast"
+	"github.com/open-policy-agent/regal/pkg/roast/transform"
+	"github.com/open-policy-agent/regal/pkg/rules"
 )
 
 // Linter stores data to use for linting.
@@ -90,10 +87,16 @@ var (
 	enabledAggregateRulesQuery = ast.MustParseBody(enabledAggregateRulesQueryStr)
 )
 
+func init() {
+	ast.InternStringTerm(
+		"eval", "disable_all", "disable_category", "disable", "enable_all", "enable_category", "enable", "ignore_files",
+	)
+}
+
 // NewLinter creates a new Regal linter.
 func NewLinter() Linter {
 	return Linter{
-		ruleBundles: []*bundle.Bundle{&rbundle.LoadedBundle},
+		ruleBundles: []*bundle.Bundle{rbundle.LoadedBundle()},
 	}
 }
 
@@ -434,7 +437,7 @@ func (l Linter) Lint(ctx context.Context) (report.Report, error) {
 		l.stopTimer(regalmetrics.RegalFilterIgnoredModules)
 	}
 
-	regoReport, err := l.lintWithRegoRules(ctx, input)
+	regoReport, err := l.lint(ctx, input)
 	if err != nil {
 		return report.Report{}, fmt.Errorf("failed to lint using Rego rules: %w", err)
 	}
@@ -466,7 +469,7 @@ func (l Linter) Lint(ctx context.Context) (report.Report, error) {
 	}
 
 	if len(allAggregates) > 0 {
-		aggregateReport, err := l.lintWithRegoAggregateRules(ctx, allAggregates, regoReport.IgnoreDirectives)
+		aggregateReport, err := l.lintWithAggregateRules(ctx, allAggregates, regoReport.IgnoreDirectives)
 		if err != nil {
 			return report.Report{}, fmt.Errorf("failed to lint using Rego aggregate rules: %w", err)
 		}
@@ -567,24 +570,18 @@ func (l Linter) GetConfig() (*config.Config, error) {
 		return l.combinedCfg, nil
 	}
 
-	regalBundle, err := l.getBundleByName("regal")
+	mergedConf, err := config.WithDefaultsFromBundle(rbundle.LoadedBundle(), l.userConfig)
 	if err != nil {
-		return &config.Config{}, fmt.Errorf("failed to get regal bundle: %w", err)
-	}
-
-	mergedConf, err := config.LoadConfigWithDefaultsFromBundle(regalBundle, l.userConfig)
-	if err != nil {
-		return &config.Config{}, fmt.Errorf("failed to read provided config: %w", err)
+		return nil, fmt.Errorf("failed to read provided config: %w", err)
 	}
 
 	if l.debugMode {
 		bs, err := yaml.Marshal(mergedConf)
 		if err != nil {
-			return &config.Config{}, fmt.Errorf("failed to marshal config: %w", err)
+			return nil, fmt.Errorf("failed to marshal config: %w", err)
 		}
 
-		log.Println("merged provided and user config:")
-		log.Println(outil.ByteSliceToString(bs))
+		log.Println("merged provided and user config:\n", outil.ByteSliceToString(bs))
 	}
 
 	return &mergedConf, nil
@@ -613,8 +610,8 @@ func (l Linter) validate(conf *config.Config) error {
 		return fmt.Errorf("failed to load custom rules: %w", l.customRuleError)
 	}
 
-	validCategories := rutil.NewSet[string]()
-	validRules := rutil.NewSet[string]()
+	validCategories := util.NewSet[string]()
+	validRules := util.NewSet[string]()
 
 	// Add all built-in rules
 	for _, b := range l.ruleBundles {
@@ -644,8 +641,8 @@ func (l Linter) validate(conf *config.Config) error {
 		validRules.Add(parts[4])
 	}
 
-	configuredCategories := rutil.NewSet(outil.Keys(conf.Rules)...)
-	configuredRules := rutil.NewSet[string]()
+	configuredCategories := util.NewSet(outil.Keys(conf.Rules)...)
+	configuredRules := util.NewSet[string]()
 
 	for _, cat := range conf.Rules {
 		configuredRules.Add(outil.Keys(cat)...)
@@ -656,24 +653,15 @@ func (l Linter) validate(conf *config.Config) error {
 	configuredCategories.Add(l.enableCategory...)
 	configuredCategories.Add(l.disableCategory...)
 
-	var invalidCategories []string
-
-	if diff := configuredCategories.Diff(validCategories); diff.Size() > 0 {
-		invalidCategories = diff.Items()
-	}
-
-	var invalidRules []string
-
-	if diff := configuredRules.Diff(validRules); diff.Size() > 0 {
-		invalidRules = diff.Items()
-	}
+	invalidCategories := configuredCategories.Diff(validCategories)
+	invalidRules := configuredRules.Diff(validRules)
 
 	switch {
-	case len(invalidCategories) > 0 && len(invalidRules) > 0:
+	case invalidCategories.Size() > 0 && invalidRules.Size() > 0:
 		return fmt.Errorf("unknown categories: %v, unknown rules: %v", invalidCategories, invalidRules)
-	case len(invalidCategories) > 0:
+	case invalidCategories.Size() > 0:
 		return fmt.Errorf("unknown categories: %v", invalidCategories)
-	case len(invalidRules) > 0:
+	case invalidRules.Size() > 0:
 		return fmt.Errorf("unknown rules: %v", invalidRules)
 	}
 
@@ -740,6 +728,7 @@ func (l Linter) prepareRegoArgs(query ast.Body) ([]func(*rego.Rego), error) {
 		rego.StoreReadAST(true),
 		rego.Metrics(l.metrics),
 		rego.ParsedQuery(query),
+		rego.Instrument(l.instrumentation),
 	}, builtins.RegalBuiltinRegoFuncs...)
 
 	if l.debugMode && l.printHook == nil {
@@ -750,10 +739,6 @@ func (l Linter) prepareRegoArgs(query ast.Body) ([]func(*rego.Rego), error) {
 		regoArgs = append(regoArgs, rego.EnablePrintStatements(true), rego.PrintHook(l.printHook))
 	}
 
-	if l.instrumentation {
-		regoArgs = append(regoArgs, rego.Instrument(true))
-	}
-
 	if l.dataBundle != nil {
 		regoArgs = append(regoArgs, rego.ParsedBundle("internal", l.dataBundle))
 	}
@@ -782,10 +767,7 @@ func (l Linter) prepareRegoArgs(query ast.Body) ([]func(*rego.Rego), error) {
 	return regoArgs, nil
 }
 
-func (l Linter) lintWithRegoRules(
-	ctx context.Context,
-	input rules.Input,
-) (report.Report, error) {
+func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, error) {
 	l.startTimer(regalmetrics.RegalLintRego)
 	defer l.stopTimer(regalmetrics.RegalLintRego)
 
@@ -793,13 +775,10 @@ func (l Linter) lintWithRegoRules(
 	defer cancel()
 
 	regoReport := report.Report{}
-	regoReport.Aggregates = make(map[string][]report.Aggregate)
-	regoReport.IgnoreDirectives = make(map[string]map[string][]string)
+	regoReport.Aggregates = make(map[string][]report.Aggregate, len(input.FileNames))
+	regoReport.IgnoreDirectives = make(map[string]map[string][]string, len(input.FileNames))
 
-	var operationCollect bool
-	if len(input.FileNames) > 1 || l.useCollectQuery {
-		operationCollect = true
-	}
+	operationCollect := len(input.FileNames) > 1 || l.useCollectQuery
 
 	var wg sync.WaitGroup
 
@@ -824,7 +803,10 @@ func (l Linter) lintWithRegoRules(
 				return
 			}
 
-			evalArgs := []rego.EvalOption{rego.EvalParsedInput(inputValue)}
+			evalArgs := []rego.EvalOption{
+				rego.EvalParsedInput(inputValue),
+				rego.EvalInstrument(l.instrumentation),
+			}
 
 			if l.baseCache != nil {
 				evalArgs = append(evalArgs, rego.EvalBaseCache(l.baseCache))
@@ -834,10 +816,6 @@ func (l Linter) lintWithRegoRules(
 				evalArgs = append(evalArgs, rego.EvalMetrics(l.metrics))
 			}
 
-			if l.instrumentation {
-				evalArgs = append(evalArgs, rego.EvalInstrument(true))
-			}
-
 			var prof *profiler.Profiler
 			if l.profiling {
 				prof = profiler.New()
@@ -851,7 +829,7 @@ func (l Linter) lintWithRegoRules(
 				return
 			}
 
-			result, err := resultSetToReport(resultSet, false)
+			result, err := report.FromResultSet(resultSet, false)
 			if err != nil {
 				errCh <- fmt.Errorf("failed to convert result set to report: %w", err)
 
@@ -905,6 +883,7 @@ func (l Linter) lintWithRegoRules(
 
 	go func() {
 		wg.Wait()
+
 		doneCh <- true
 	}()
 
@@ -918,7 +897,7 @@ func (l Linter) lintWithRegoRules(
 	}
 }
 
-func (l Linter) lintWithRegoAggregateRules(
+func (l Linter) lintWithAggregateRules(
 	ctx context.Context,
 	aggregates map[string][]report.Aggregate,
 	ignoreDirectives map[string]map[string][]string,
@@ -951,7 +930,10 @@ func (l Linter) lintWithRegoAggregateRules(
 		return report.Report{}, fmt.Errorf("failed to transform input value: %w", err)
 	}
 
-	evalArgs := []rego.EvalOption{rego.EvalParsedInput(inputValue)}
+	evalArgs := []rego.EvalOption{
+		rego.EvalParsedInput(inputValue),
+		rego.EvalInstrument(l.instrumentation),
+	}
 
 	if l.metrics != nil {
 		evalArgs = append(evalArgs, rego.EvalMetrics(l.metrics))
@@ -968,7 +950,7 @@ func (l Linter) lintWithRegoAggregateRules(
 		return report.Report{}, fmt.Errorf("error encountered in query evaluation %w", err)
 	}
 
-	result, err := resultSetToReport(resultSet, true)
+	result, err := report.FromResultSet(resultSet, true)
 	if err != nil {
 		return report.Report{}, fmt.Errorf("failed to convert result set to report: %w", err)
 	}
@@ -990,48 +972,6 @@ func (l Linter) lintWithRegoAggregateRules(
 	return result, nil
 }
 
-func resultSetToReport(resultSet rego.ResultSet, aggregate bool) (report.Report, error) {
-	if len(resultSet) != 1 {
-		return report.Report{}, fmt.Errorf("expected 1 item in resultset, got %d", len(resultSet))
-	}
-
-	r := report.Report{}
-
-	if aggregate {
-		if binding, ok := resultSet[0].Bindings["lint"].(map[string]any); ok {
-			if aggregateBinding, ok := binding["aggregate"]; ok {
-				if err := encoding.JSONRoundTrip(aggregateBinding, &r); err != nil {
-					return report.Report{}, fmt.Errorf("JSON rountrip failed for bindings: %v %w", binding, err)
-				}
-			}
-		}
-	} else {
-		if binding, ok := resultSet[0].Bindings["lint"]; ok {
-			if err := encoding.JSONRoundTrip(binding, &r); err != nil {
-				return report.Report{}, fmt.Errorf("JSON rountrip failed for bindings: %v %w", binding, err)
-			}
-		}
-	}
-
-	return r, nil
-}
-
-func (l Linter) getBundleByName(name string) (*bundle.Bundle, error) {
-	if l.ruleBundles == nil {
-		return nil, errors.New("no bundles loaded")
-	}
-
-	for _, ruleBundle := range l.ruleBundles {
-		if metadataName, ok := ruleBundle.Manifest.Metadata["name"].(string); ok {
-			if metadataName == name {
-				return ruleBundle, nil
-			}
-		}
-	}
-
-	return nil, errors.New("no regal bundle found")
-}
-
 func (l Linter) startTimer(name string) {
 	if l.metrics != nil {
 		l.metrics.Timer(name).Start()
