@@ -3,6 +3,10 @@ package report
 import (
 	"fmt"
 	"sort"
+
+	"github.com/open-policy-agent/opa/v1/rego"
+
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 )
 
 // RelatedResource provides documentation on a violation.
@@ -49,12 +53,64 @@ type Notice struct {
 	Severity    string `json:"severity"`
 }
 
+type Summary struct {
+	FilesScanned  int `json:"files_scanned"`
+	FilesFailed   int `json:"files_failed"`
+	RulesSkipped  int `json:"rules_skipped"`
+	NumViolations int `json:"num_violations"`
+}
+
+// Report aggregate of Violation as returned by a linter run.
+type Report struct {
+	// We don't have aggregates when publishing the final report (see JSONReporter), so omitempty is needed here
+	// to avoid surfacing a null/empty field.
+	Aggregates       map[string][]Aggregate         `json:"aggregates,omitempty"`
+	Metrics          map[string]any                 `json:"metrics,omitempty"`
+	AggregateProfile map[string]ProfileEntry        `json:"-"`
+	IgnoreDirectives map[string]map[string][]string `json:"ignore_directives,omitempty"`
+	Violations       []Violation                    `json:"violations"`
+	Notices          []Notice                       `json:"notices,omitempty"`
+	Profile          []ProfileEntry                 `json:"profile,omitempty"`
+	Summary          Summary                        `json:"summary"`
+}
+
+// ProfileEntry is a single entry of profiling information, keyed by location.
+// This data may have been aggregated across multiple runs.
+type ProfileEntry struct {
+	Location    string `json:"location"`
+	TotalTimeNs int64  `json:"total_time_ns"`
+	NumEval     int    `json:"num_eval"`
+	NumRedo     int    `json:"num_redo"`
+	NumGenExpr  int    `json:"num_gen_expr"`
+}
+
 // An Aggregate is data collected by some rule while processing a file AST, to be used later by other rules needing a
 // global context (i.e. broader than per-file)
 // Rule authors are expected to collect the minimum needed data, to avoid performance problems
 // while working with large Rego code repositories.
 type Aggregate map[string]any
 
+func FromResultSet(resultSet rego.ResultSet, aggregate bool) (r Report, err error) {
+	if len(resultSet) != 1 {
+		return r, fmt.Errorf("expected 1 item in resultset, got %d", len(resultSet))
+	}
+
+	var binding any
+
+	if lb, ok := resultSet[0].Bindings["lint"].(map[string]any); ok {
+		binding = lb
+		if aggregateBinding, ok := lb["aggregate"]; ok && aggregate {
+			binding = aggregateBinding
+		}
+
+		if err = encoding.JSONRoundTrip(binding, &r); err != nil {
+			err = fmt.Errorf("JSON rountrip failed for bindings: %v %w", binding, err)
+		}
+	}
+
+	return r, err
+}
+
 func (a Aggregate) SourceFile() string {
 	source, ok := a["aggregate_source"].(map[string]any)
 	if !ok {
@@ -91,37 +147,6 @@ func (a Aggregate) IndexKey() string {
 	return fmt.Sprintf("%s/%s", cat, title)
 }
 
-type Summary struct {
-	FilesScanned  int `json:"files_scanned"`
-	FilesFailed   int `json:"files_failed"`
-	RulesSkipped  int `json:"rules_skipped"`
-	NumViolations int `json:"num_violations"`
-}
-
-// Report aggregate of Violation as returned by a linter run.
-type Report struct {
-	// We don't have aggregates when publishing the final report (see JSONReporter), so omitempty is needed here
-	// to avoid surfacing a null/empty field.
-	Aggregates       map[string][]Aggregate         `json:"aggregates,omitempty"`
-	Metrics          map[string]any                 `json:"metrics,omitempty"`
-	AggregateProfile map[string]ProfileEntry        `json:"-"`
-	IgnoreDirectives map[string]map[string][]string `json:"ignore_directives,omitempty"`
-	Violations       []Violation                    `json:"violations"`
-	Notices          []Notice                       `json:"notices,omitempty"`
-	Profile          []ProfileEntry                 `json:"profile,omitempty"`
-	Summary          Summary                        `json:"summary"`
-}
-
-// ProfileEntry is a single entry of profiling information, keyed by location.
-// This data may have been aggregated across multiple runs.
-type ProfileEntry struct {
-	Location    string `json:"location"`
-	TotalTimeNs int64  `json:"total_time_ns"`
-	NumEval     int    `json:"num_eval"`
-	NumRedo     int    `json:"num_redo"`
-	NumGenExpr  int    `json:"num_gen_expr"`
-}
-
 func (r *Report) AddProfileEntries(prof map[string]ProfileEntry) {
 	if r.AggregateProfile == nil {
 		r.AggregateProfile = map[string]ProfileEntry{}
