@@ -1,4 +1,3 @@
-//nolint:wrapcheck
 package reporter
 
 import (
@@ -16,14 +15,13 @@ import (
 
 	outil "github.com/open-policy-agent/opa/v1/util"
 
-	"github.com/styrainc/regal/internal/mode"
-	"github.com/styrainc/regal/internal/novelty"
-	"github.com/styrainc/regal/pkg/fixer"
-	"github.com/styrainc/regal/pkg/fixer/fixes"
-	"github.com/styrainc/regal/pkg/report"
-
-	"github.com/styrainc/roast/pkg/encoding"
-	"github.com/styrainc/roast/pkg/util"
+	"github.com/open-policy-agent/regal/internal/mode"
+	"github.com/open-policy-agent/regal/internal/novelty"
+	"github.com/open-policy-agent/regal/internal/util"
+	"github.com/open-policy-agent/regal/pkg/fixer"
+	"github.com/open-policy-agent/regal/pkg/fixer/fixes"
+	"github.com/open-policy-agent/regal/pkg/report"
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 )
 
 // Reporter releases linter reports in a format decided by the implementation.
@@ -163,8 +161,7 @@ func (tr PrettyReporter) Publish(_ context.Context, r report.Report) error {
 		return nil
 	}
 
-	f := fixer.NewFixer()
-	f.RegisterFixes(fixes.NewDefaultFixes()...)
+	f := fixer.NewFixer().RegisterFixes(fixes.NewDefaultFixes()...)
 
 	fixableViolations := util.NewSet[string]()
 
@@ -298,7 +295,7 @@ func (tr CompactReporter) Publish(_ context.Context, r report.Report) error {
 	summary := fmt.Sprintf("%d %s linted , %d %s found.",
 		r.Summary.FilesScanned, pluralize("file", r.Summary.FilesScanned),
 		r.Summary.NumViolations, pluralize("violation", r.Summary.NumViolations))
-	// rendering the table
+
 	table.Render()
 
 	_, err := fmt.Fprintln(tr.out, strings.TrimSuffix(sb.String(), ""), summary)
@@ -330,9 +327,7 @@ func (tr GitHubReporter) Publish(ctx context.Context, r report.Report) error {
 		return err
 	}
 
-	if r.Violations == nil {
-		r.Violations = []report.Violation{}
-	}
+	r.Violations = util.NullToEmpty(r.Violations)
 
 	for _, violation := range r.Violations { //nolint:gocritic
 		if _, err := fmt.Fprintf(tr.out,
