@@ -1,11 +1,12 @@
 package rules
 
 import (
+	"path/filepath"
 	"testing"
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/internal/parse"
+	"github.com/open-policy-agent/regal/internal/parse"
 )
 
 func TestInputFromTextWithOptions(t *testing.T) {
@@ -119,7 +120,7 @@ func TestRegoVersionFromVersionsMap(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 
-			actualVersion := RegoVersionFromVersionsMap(tc.VersionsMap, tc.Filename, ast.RegoUndefined)
+			actualVersion := RegoVersionFromMap(tc.VersionsMap, filepath.FromSlash(tc.Filename), ast.RegoUndefined)
 			if actualVersion != tc.ExpectedVersion {
 				t.Errorf("Expected %v, got %v", tc.ExpectedVersion, actualVersion)
 			}
